@@ -4,12 +4,15 @@
 *                                                                              *
 *                              T A B B O O K . C                               *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: TabBook.c,v 1.1 2000/12/10 15:40:30 jrh Exp $
+* $Id: TabBook.c,v 1.2 2003/11/07 11:20:49 jrh Exp $
 * $Log: TabBook.c,v $
+* Revision 1.2  2003/11/07 11:20:49  jrh
+* Release 2.4
+*
 * Revision 1.1  2000/12/10 15:40:30  jrh
 * Initial revision
 *
@@ -59,6 +62,9 @@ USAGE:		See Actual Functions For Description
 /* Revision History:
 
 $Log: TabBook.c,v $
+Revision 1.2  2003/11/07 11:20:49  jrh
+Release 2.4
+
 Revision 1.1  2000/12/10 15:40:30  jrh
 Initial revision
 
@@ -77,8 +83,7 @@ Guard against realizing with no children
 $log
 */
 
-#define 	VERSION "$Revision: 1.1 $"
-#ident		"@(#)$Id: TabBook.c,v 1.1 2000/12/10 15:40:30 jrh Exp $ $Revision: 1.1 $"
+#define 	VERSION "$Revision: 1.2 $"
 
 
 
@@ -92,6 +97,7 @@ $log
 #include <Xm/BulletinB.h>
 #include <Xm/BulletinBP.h>
 #include <Xm/PushB.h>
+#include <Xm/XmStrDefs.h>
 #else
 #include <X11/Xaw/Box.h>
 #include <X11/Xaw/Command.h>
