@@ -4,12 +4,15 @@
 *                                                                              *
 *                            B A S I S F O R M . C                             *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: basisform.c,v 1.5 2000/12/10 15:01:42 jrh Exp $
+* $Id: basisform.c,v 1.6 2003/11/07 10:57:42 jrh Exp $
 * $Log: basisform.c,v $
+* Revision 1.6  2003/11/07 10:57:42  jrh
+* Release 2.4
+*
 * Revision 1.5  2000/12/10 15:01:42  jrh
 * Release 2.3
 *
@@ -53,8 +56,8 @@ extern void MapBox(Widget, caddr_t, XmAnyCallbackStruct *);
 extern Widget CreateToggleBox(Widget, struct PushButtonRow *, int, int,
                               int, int, int);
 extern char *getStringResource(Widget, char *);
-extern char *bfname(int);
-extern void bfnamn(int, int *, int*);
+/* extern char *bfname(int);
+extern void bfnamn(int, int *, int*);*/
 extern void *getmem(size_t, size_t);
 extern void CreatePushButtonRow(Widget, struct PushButtonRow *, int);
 extern void calcmo(void);
@@ -80,7 +83,7 @@ void basisDialog(int bfAtom)
     { "cancel", basisDialogExit, (XtPointer)FALSE, NULL }
   };
   struct PushButtonRow *radiobox_buttons;
-  int start, end;
+/*int start, end;*/
   char *label, *word, aname[MAXLENLINE];
   register int i, j;
 
@@ -110,26 +113,32 @@ void basisDialog(int bfAtom)
                          XmNleftAttachment, XmATTACH_FORM,
                          XmNrightAttachment, XmATTACH_FORM,
                          NULL);
-  bfnamn(bfAtom, &start, &end);
-  radiobox_buttons=(struct PushButtonRow *)getmem(end-start+2, sizeof(struct PushButtonRow));
-  label=(char *)getmem(end-start+1, 19*sizeof(char));
+/*bfnamn(bfAtom, &start, &end);
+  radiobox_buttons=(struct PushButtonRow *)getmem(end-start+2, sizeof(struct PushButtonRow)); */
+  radiobox_buttons=(struct PushButtonRow *)getmem(mol->atoms[bfAtom].nBasisFunctions+1, sizeof(struct PushButtonRow));
+/*label=(char *)getmem(end-start+1, 19*sizeof(char));*/
+  label=(char *)getmem(mol->atoms[bfAtom].nBasisFunctions, 19*sizeof(char));
   j=0;
-  for (i=start; i<=end; i++)
+/*for (i=start; i<=end; i++)*/
+  for (i=0; i<mol->atoms[bfAtom].nBasisFunctions; i++)
   {
     if (iwavef == BASIS_IN_MO)
     {
-      sprintf(&label[19*j], "%10.6f*%s", mol->orbitals[mol->imo].coeff[i], bfname(i));
+/*    sprintf(&label[19*j], "%10.6f*%s", mol->orbitals[mol->imo].coeff[i], bfname(i));*/
+      sprintf(&label[19*j], "%10.6f*%s", mol->orbitals[mol->imo].coeff[i], mol->atoms[bfAtom].basisFunctionNames[i]);
       radiobox_buttons[j].label=&(label[19*j]);
     }
     else
-      radiobox_buttons[j].label=bfname(i);
+/*    radiobox_buttons[j].label=bfname(i);*/
+      radiobox_buttons[j].label=mol->atoms[bfAtom].basisFunctionNames[i];
     radiobox_buttons[j].callback=getBasisfunction;
     radiobox_buttons[j].client_data=(XtPointer)i;
     radiobox_buttons[j++].widget=(Widget)NULL;
   }
   radiobox=CreateToggleBox(form1, radiobox_buttons, j, (int)XmVERTICAL, j/10+1,
                            True, 0);
-  mol->ibasfu=start;
+/*mol->ibasfu=start;*/
+  mol->ibasfu=0;
   sep=XtVaCreateManagedWidget("sep", xmSeparatorWidgetClass, form1,
                               XmNorientation, XmHORIZONTAL,
                               XmNtraversalOn, False,
