@@ -8,8 +8,11 @@
 *                                                                              *
 ********************************************************************************
 *
-* $Id: bio.c,v 1.6 2003/11/07 10:57:49 jrh Exp $
+* $Id: bio.c,v 1.7 2004/08/29 14:48:09 jrh Exp $
 * $Log: bio.c,v $
+* Revision 1.7  2004/08/29 14:48:09  jrh
+* Release 2.4.1
+*
 * Revision 1.6  2003/11/07 10:57:49  jrh
 * Release 2.4
 *
@@ -42,6 +45,7 @@
 
 int readFrame(FILE *, int, int, double, int, long *);
 void readNormalModes(FILE *);
+void readXtlFile(FILE *);
 extern void *getmem(size_t, size_t);
 extern void fremem(void **);
 
@@ -59,12 +63,20 @@ int main(int argc, char **argv)
     exit(-1);
   }
   fgets(line, MAXLENLINE, mainfile);
-  if (strstr(line, "!BIOSYM archive") == NULL)
+  if (strstr(line, "!BIOSYM archive") == NULL &&
+      strstr(line, "TITLE") == NULL)
   {
     printf("$error wrongFiletype 1 %s\n", argv[1]);
     printf("$end\n");
     exit(-1);
   }
+  if (strstr(line, "TITLE") != NULL)
+  {
+    printf("$title\n%s", &line[6]);
+    readXtlFile(mainfile);
+    return(0);
+  }
+
   sscanf(line+15, "%d", &version);
 /*if (version < 2)
   {
@@ -159,3 +171,56 @@ void readNormalModes(FILE *file)
     }
   }
 }
+
+void readXtlFile(FILE *file)
+{
+  double x, y, z;
+  int first=TRUE;
+  char line[MAXLENLINE], *word;
+
+  while (fgets(line, MAXLENLINE, file) != NULL)
+  {
+    if (strstr(line, "CELL") != NULL)
+    {
+      fgets(line, MAXLENLINE, file);
+      printf("$unitcell %s", line);
+    }
+    else if (strstr(line, "SYMMETRY") != NULL)
+    {
+      word=strstr(line, "LABEL");
+      if (word)
+      {
+        printf("$symmetry %s", word+6);
+      }
+    }
+    else if (strstr(line, "ATOMS") != NULL)
+    {
+      fgets(line, MAXLENLINE, file);
+      while (fgets(line, MAXLENLINE, file) != NULL)
+      {
+        if (strstr(line, "EOF"))
+	{
+	  printf("$end\n");
+	  return;
+	}
+	word=strtok(line, " \t");
+	word=strtok(NULL, " \t");
+	x=atof(word);
+	word=strtok(NULL, " \t");
+	y=atof(word);
+	word=strtok(NULL, " \t");
+	z=atof(word);
+	word=strtok(NULL, " \t");
+	word=strtok(NULL, " \t");
+	word=strtok(NULL, " \t");
+	word=strtok(NULL, " \t");
+	if (first)
+	{
+	  first=FALSE;
+	  printf("$coord fractional 1.0\n");
+	}
+	printf("%22.14f%22.14f%22.14f %c%c\n", x, y, z, toupper(word[0]), tolower(word[1]));
+      }
+    }
+  }
+}
