@@ -4,12 +4,15 @@
 *                                                                              *
 *                               C A L C M O . C                                *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: calcmo.c,v 1.5 2000/12/10 15:02:43 jrh Exp $
+* $Id: calcmo.c,v 1.6 2003/11/07 10:58:35 jrh Exp $
 * $Log: calcmo.c,v $
+* Revision 1.6  2003/11/07 10:58:35  jrh
+* Release 2.4
+*
 * Revision 1.5  2000/12/10 15:02:43  jrh
 * Release 2.3
 *
@@ -38,7 +41,7 @@
 #include "viewmol.h"
 #include "dialog.h"
 
-void setGridObject(struct GRIDOBJECT *, double, int, int, int);
+void setGridObject(struct GRIDOBJECT *, double, double, int, int, int);
 
 extern double makemo(struct ATOM *, struct ORBITAL *, double, double, double,
                      int, int, int, int);
@@ -49,7 +52,7 @@ extern void *getmem(size_t, size_t);
 extern void *expmem(void *, size_t, size_t);
 extern void setCursor(Widget, int);
 extern int norbs(struct MOLECULE *);
-extern char *bfname(int);
+/* extern char *bfname(int);*/
 extern void fremem(void **);
 extern void restoreGeometry(struct SAVE *, int);
 extern int  messgb(Widget, int, char *, struct PushButtonRow *, int);
@@ -82,15 +85,15 @@ void calcmo(void)
     molecules[imol].ngridobjects++;
     molecules[imol].gridObjects=(struct GRIDOBJECT *)getmem(molecules[imol].ngridobjects,
                                  sizeof(struct GRIDOBJECT));
-    setGridObject(&(molecules[imol].gridObjects[0]), gridres, iwavef,
-                  molecules[imol].imo, molecules[imol].ibasfu);
+    setGridObject(&(molecules[imol].gridObjects[0]), windows[VIEWER].far,
+                  gridres, iwavef, molecules[imol].imo, molecules[imol].ibasfu);
   }
   else
   {
     j=FALSE;
     for (i=0; i<molecules[imol].ngridobjects; i++)
     {
-      if (molecules[imol].gridObjects[i].type == iwavef)
+      if ((molecules[imol].gridObjects[i].type & ~GRIDREAD) == iwavef)
       {
         if ((iwavef == MOLECULAR_ORBITAL &&
              molecules[imol].gridObjects[i].mo == molecules[imol].imo) ||
@@ -115,7 +118,8 @@ void calcmo(void)
     if (!j) molecules[imol].gridObjects=(struct GRIDOBJECT *)expmem(molecules[imol].gridObjects,
                                          molecules[imol].ngridobjects+1, sizeof(struct GRIDOBJECT));
     setGridObject(&(molecules[imol].gridObjects[molecules[imol].ngridobjects]),
-                  gridres, iwavef, molecules[imol].imo, molecules[imol].ibasfu);
+                  windows[VIEWER].far, gridres, iwavef, molecules[imol].imo,
+			molecules[imol].ibasfu);
     molecules[imol].ngridobjects++;
   }
 
@@ -356,11 +360,29 @@ int runMoloch(double *grid, double gridres, double box, double step, int imo,
   return(FALSE);
 }
 
-void setGridObject(struct GRIDOBJECT *gridObject, double gridres, int iwavef,
-                   int imo, int ibasfu)
+void setGridObject(struct GRIDOBJECT *gridObject, double start, double gridres,
+                   int iwavef, int imo, int ibasfu)
 {
   char *word;
 
+  gridObject->origin[0]=0.0;
+  gridObject->origin[1]=0.0;
+  gridObject->origin[2]=0.0;
+  gridObject->vector1[0]=1.0;
+  gridObject->vector1[1]=0.0;
+  gridObject->vector1[2]=0.0;
+  gridObject->vector2[0]=0.0;
+  gridObject->vector2[1]=1.0;
+  gridObject->vector2[2]=0.0;
+  gridObject->vector3[0]=0.0;
+  gridObject->vector3[1]=0.0;
+  gridObject->vector3[2]=1.0;
+  gridObject->start[0]=gridObject->start[1]=gridObject->start[2]=(-start);
+  gridObject->step[0]=gridObject->step[1]=gridObject->step[2]=2.0*start/gridres;
+  gridObject->ngridpoints[0]=gridObject->ngridpoints[1]=gridObject->ngridpoints[2]=(int)gridres;
+  gridObject->npoints[0]=gridObject->ngridpoints[0];
+  gridObject->npoints[1]=gridObject->ngridpoints[1];
+  gridObject->npoints[2]=gridObject->ngridpoints[2];
   gridObject->resolution=gridres;
   gridObject->type=iwavef;
   gridObject->mo=imo;
@@ -370,13 +392,15 @@ void setGridObject(struct GRIDOBJECT *gridObject, double gridres, int iwavef,
     case BASIS_FUNCTION:    word=getStringResource(topShell, "basisfunctionTitle");
                             sprintf(gridObject->text, word, ibasfu+1,
                                     molecules[imol].atoms[bfatom].name,
-                                    bfatom+1, bfname(ibasfu));
+/*                                  bfatom+1, bfname(ibasfu));*/
+                                    bfatom+1, molecules[imol].atoms[bfatom].basisFunctionNames[ibasfu]);
                             break;
     case BASIS_IN_MO:       word=getStringResource(topShell, "basisfunctionInMOTitle");
                             sprintf(gridObject->text, word, ibasfu+1, imo+1,
                                     molecules[imol].atoms[bfatom].name, bfatom+1,
                                     molecules[imol].orbitals[imo].coeff[ibasfu],
-                                    bfname(ibasfu));
+/*                                  bfname(ibasfu));*/
+                                    molecules[imol].atoms[bfatom].basisFunctionNames[ibasfu]);
                             break;
     case MOLECULAR_ORBITAL: word=getStringResource(topShell, "molecularOrbitalTitle");
                             sprintf(gridObject->text, word, imo+1,
