@@ -8,8 +8,11 @@
 *                                                                              *
 ********************************************************************************
 *
-* $Id: cellform.c,v 1.4 2003/11/07 10:58:46 jrh Exp $
+* $Id: cellform.c,v 1.5 2004/08/29 14:49:02 jrh Exp $
 * $Log: cellform.c,v $
+* Revision 1.5  2004/08/29 14:49:02  jrh
+* Release 2.4.1
+*
 * Revision 1.4  2003/11/07 10:58:46  jrh
 * Release 2.4
 *
@@ -50,7 +53,7 @@ void makeMillerPlane(Widget, struct SLIDER *, XmScrollBarCallbackStruct *);
 extern void GetSlider(Widget, struct SLIDER *, XmScrollBarCallbackStruct *);
 extern void drawMolecule(Widget, caddr_t, XmDrawingAreaCallbackStruct *);
 extern int redraw(int);
-extern void expandCell(int);
+extern void expandCell(int, int);
 extern void millerPlane(void);
 extern void MapBox(Widget, caddr_t, XmToggleButtonCallbackStruct *);
 extern Widget CreatePushButtonRow(Widget, struct PushButtonRow *, int);
@@ -181,7 +184,7 @@ void unitcellExit(Widget button, caddr_t which,
       mol->unitcell->factor[0]=cellFactor_save[0];
       mol->unitcell->factor[1]=cellFactor_save[1];
       mol->unitcell->factor[2]=cellFactor_save[2];
-      expandCell(TRUE);
+      expandCell(TRUE, TRUE);
     }
     mol->unitcell->miller[0]=miller_save[0];
     mol->unitcell->miller[1]=miller_save[1];
@@ -210,7 +213,7 @@ void setCellSliders(struct MOLECULE *mol)
 void makeNewCell(Widget w, struct SLIDER *slider, XmScrollBarCallbackStruct *data)
 {
   GetSlider(w, slider, data);
-  expandCell(TRUE);
+  expandCell(TRUE, TRUE);
   redraw(VIEWER);
 }
 
