@@ -4,12 +4,15 @@
 *                                                                              *
 *                              C O L E D I T . C                               *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: coledit.c,v 1.5 2000/12/10 15:03:02 jrh Exp $
+* $Id: coledit.c,v 1.6 2003/11/07 10:58:54 jrh Exp $
 * $Log: coledit.c,v $
+* Revision 1.6  2003/11/07 10:58:54  jrh
+* Release 2.4
+*
 * Revision 1.5  2000/12/10 15:03:02  jrh
 * Release 2.3
 *
@@ -98,14 +101,14 @@ void colorEditor(Widget widget, caddr_t which, XmAnyCallbackStruct *data)
     { "ok", colorEditorExit, (XtPointer)TRUE, NULL },
     { "cancel", colorEditorExit, (XtPointer)FALSE, NULL }
   };
-  static char selectedData[] = {
+  static unsigned char selectedData[] = {
     0xff, 0xff, 0xff, 0x01, 0x00, 0x80, 0x01, 0x00, 0xb8, 0x01, 0x00, 0xb8,
     0x01, 0x00, 0x9c, 0x01, 0x00, 0x9c, 0x01, 0x00, 0x8e, 0x01, 0x00, 0x8e,
     0x01, 0x00, 0x87, 0x01, 0x00, 0x87, 0x01, 0x80, 0x83, 0x01, 0x80, 0x83,
     0x01, 0x80, 0x81, 0x19, 0xc0, 0x81, 0x39, 0xc0, 0x80, 0x71, 0xe0, 0x80,
     0xe1, 0x60, 0x80, 0xc1, 0x71, 0x80, 0x81, 0x33, 0x80, 0x01, 0x3f, 0x80,
     0x01, 0x1e, 0x80, 0x01, 0x1c, 0x80, 0x01, 0x00, 0x80, 0xff, 0xff, 0xff};
-  static char unselectedData[] = {
+  static unsigned char unselectedData[] = {
     0xff, 0xff, 0xff, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
     0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
     0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80, 0x01, 0x00, 0x80,
@@ -199,9 +202,9 @@ void colorEditor(Widget widget, caddr_t which, XmAnyCallbackStruct *data)
     sprintf(buttonName, "button%1d", i);
     p=getPixel(i);
     selected=XCreatePixmapFromBitmapData(XtDisplay(dialog), XtWindow(dialog),
-                                         selectedData, 24, 24, stdcol[j], p, depth);
+                                         (char *)selectedData, 24, 24, stdcol[j], p, depth);
     unselected=XCreatePixmapFromBitmapData(XtDisplay(dialog), XtWindow(dialog),
-                                           unselectedData, 24, 24, stdcol[BLACK], p, depth);
+                                           (char *)unselectedData, 24, 24, stdcol[BLACK], p, depth);
     button[i]=XtVaCreateManagedWidget(buttonName, xmToggleButtonWidgetClass, form1,
                                       XmNlabelType, XmPIXMAP,
                                       XmNlabelPixmap, unselected,
