@@ -8,8 +8,11 @@
 *                                                                              *
 ********************************************************************************
 *
-* $Id: draw.c,v 1.6 2003/11/07 10:59:34 jrh Exp $
+* $Id: draw.c,v 1.7 2004/08/29 14:49:57 jrh Exp $
 * $Log: draw.c,v $
+* Revision 1.7  2004/08/29 14:49:57  jrh
+* Release 2.4.1
+*
 * Revision 1.6  2003/11/07 10:59:34  jrh
 * Release 2.4
 *
@@ -124,22 +127,6 @@ extern int iwavef, interp, debug, setins, nAnnotations;
 extern double *grid, level, weight;
 extern char *formBondLength, *formBondAngle, *formTorsionAngle;
 
-typedef struct point {           /* a three-dimensional point */
-    double x, y, z;              /* its coordinates */
-} POINT;
-
-typedef struct vertex {          /* surface vertex */
-    POINT position, normal;      /* position and surface normal */
-} VERTEX;
-
-typedef struct vertices {        /* list of vertices in polygonization */
-    int count, max;              /* # vertices, max # allowed */
-    VERTEX *ptr;           /* dynamically allocated */
-} VERTICES;      
-
-int triproc(int, int, int, VERTICES);
-double searchGrid(double, double, double);
-
 void drawBackground(int window, Pixel color, double depthBufferClear)
 {
   float background_rgb[4] = {0.0, 0.0, 1.0, 0.0};
