@@ -4,12 +4,15 @@
 *                                                                              *
 *                                  E O F . C                                   *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: eof.c,v 1.3 2000/12/10 15:06:50 jrh Exp $
+* $Id: eof.c,v 1.4 2003/11/07 11:01:34 jrh Exp $
 * $Log: eof.c,v $
+* Revision 1.4  2003/11/07 11:01:34  jrh
+* Release 2.4
+*
 * Revision 1.3  2000/12/10 15:06:50  jrh
 * Release 2.3
 *
@@ -21,6 +24,7 @@
 *
 */
 #include<stdio.h>
+#include<stdlib.h>
 
 void eof(char *type, char *file, int terminate)
 {
