@@ -8,8 +8,11 @@
 *                                                                              *
 ********************************************************************************
 *
-* $Id: fallbacks.h,v 1.6 2003/11/07 12:48:48 jrh Exp $
+* $Id: fallbacks.h,v 1.7 2004/08/29 14:50:37 jrh Exp $
 * $Log: fallbacks.h,v $
+* Revision 1.7  2004/08/29 14:50:37  jrh
+* Release 2.4.1
+*
 * Revision 1.6  2003/11/07 12:48:48  jrh
 * Release 2.4
 *
@@ -110,6 +113,7 @@ static String fallbacks[] = {
   "Viewmol.history.history.font:                    variable",
   "Viewmol.MODiagram.MODiagram.font:                variable",
   "Viewmol.MODiagram.MODiagram.greekFont:           -adobe-symbol-medium-r-normal--14-*",
+  "Viewmol.viewer.delay:                            0",
   "Viewmol.viewer.background:                       white",
   "Viewmol.viewer.foreground:                       gray75",
   "Viewmol.spectrum.spectrum.background:            white",
@@ -503,6 +507,7 @@ static String fallbacks[] = {
   "Viewmol*configurationForm*pl.labelString:        Polish",
   "Viewmol*configurationForm*ru.labelString:        Russian",
   "Viewmol*configurationForm*es.labelString:        Spanish",
+  "Viewmol*configurationForm*tr.labelString:        Turkish",
   "Viewmol*configurationForm*browserLabel.labelString: Location of Web browser",
   "Viewmol*configurationForm*molochLabel.labelString:    Location of Moloch",
   "Viewmol*configurationForm*raytracerLabel.labelString:  Location of Povray",
