@@ -4,12 +4,15 @@
 *                                                                              *
 *                             F E E D B A C K . C                              *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: feedback.c,v 1.4 2000/12/10 15:07:06 jrh Exp $
+* $Id: feedback.c,v 1.5 2003/11/07 11:01:52 jrh Exp $
 * $Log: feedback.c,v $
+* Revision 1.5  2003/11/07 11:01:52  jrh
+* Release 2.4
+*
 * Revision 1.4  2000/12/10 15:07:06  jrh
 * Release 2.3
 *
@@ -60,7 +63,7 @@ void (*point)(FILE *, int, GLfloat, GLfloat);
 void (*lineStipple)(FILE *, GLushort);
 void (*showString)(FILE *, int, GLfloat, GLfloat);
 
-void feedbackString(char *, double, double, double, double, GLuint);
+void feedbackString(char *, double, double, double, double, GLuint, char);
 void feedbackLineStipple(GLint, GLushort);
 void feedbackLineWidth(GLfloat);
 void feedbackDisable(GLenum);
@@ -514,16 +517,17 @@ void writeFeedback(FILE * file, GLint size, GLfloat *buffer, int window,
   }
 }
 
-void feedbackString(char *s, double x, double y, double z, double offset, GLuint dummy)
+void feedbackString(char *s, double x, double y, double z, double width,
+                    GLuint dummy, char align)
 {
   GLubyte bitmap[] = {0};
+  char alignment[2];
 
   glRasterPos3d(x, y, z);
   glBitmap(1, 1, 1, 1, 1, 1, bitmap);
-  if (offset == 0.0)
-    strcpy(textPointer, "l");
-  else
-    strcpy(textPointer, "r");
+  alignment[0]=align;
+  alignment[1]='\0';
+  strcpy(textPointer, alignment);
   textPointer++;
   while (*s == ' ') s++;
   strcat(textPointer, s);
