@@ -4,12 +4,15 @@
 *                                                                              *
 *                           F I L E S E L E C T . C                            *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: fileselect.c,v 1.5 2000/12/10 15:07:14 jrh Exp $
+* $Id: fileselect.c,v 1.6 2003/11/07 11:02:00 jrh Exp $
 * $Log: fileselect.c,v $
+* Revision 1.6  2003/11/07 11:02:00  jrh
+* Release 2.4
+*
 * Revision 1.5  2000/12/10 15:07:14  jrh
 * Release 2.3
 *
@@ -26,13 +29,13 @@
 * Initial revision
 *
 */
+#include<sys/types.h>
 #include<dirent.h>
 #include<fnmatch.h>
 #include<stdio.h>
 #include<stdlib.h>
 #include<unistd.h>
 #include<sys/stat.h>
-#include<sys/types.h>
 #include<X11/Xlib.h>
 #include<X11/Intrinsic.h>
 #include<Xm/Xm.h>
@@ -49,7 +52,7 @@ extern int alphasort(struct dirent **, struct dirent **);
 static void GetFilename(Widget, char **, XmFileSelectionBoxCallbackStruct *);
 static void Cancel(Widget, char **, caddr_t);
 extern void MapBox(Widget, caddr_t, XmAnyCallbackStruct *);
-#ifdef LINUX
+#if defined LINUX || defined DARWIN
 static int matchFileNames(const struct dirent *);
 static int matchDirNames(const struct dirent *);
 #else
@@ -137,7 +140,7 @@ static void Cancel(Widget button, char **client_data, caddr_t call_data)
   cont=FALSE;
 }
 
-#ifdef LINUX
+#if defined LINUX || defined DARWIN
 int matchFileNames(const struct dirent *d)
 #else
 int matchFileNames(struct dirent *d)
@@ -158,7 +161,7 @@ int matchFileNames(struct dirent *d)
   return(1);
 }
 
-#ifdef LINUX
+#if defined LINUX || defined DARWIN
 int matchDirNames(const struct dirent *d)
 #else
 int matchDirNames(struct dirent *d)
