@@ -8,8 +8,11 @@
 *                                                                              *
 ********************************************************************************
 *
-* $Id: init.c,v 1.6 2003/11/07 11:04:56 jrh Exp $
+* $Id: init.c,v 1.7 2004/08/29 14:52:00 jrh Exp $
 * $Log: init.c,v $
+* Revision 1.7  2004/08/29 14:52:00  jrh
+* Release 2.4.1
+*
 * Revision 1.6  2003/11/07 11:04:56  jrh
 * Release 2.4
 *
@@ -416,7 +419,11 @@ void initMODiagram(Widget w, caddr_t client_data, caddr_t call_data)
   string=getStringResource(windows[MO].widget, "font");
   windows[MO].font=makeRasterFont(XtDisplay(windows[MO].widget), string,
                                   &windows[MO].GLfontId);
-  string=getStringResource(windows[MO].widget, "greekFont");
+  /* It seems that under Linux the greekFont resource, although set
+     in the fallbacks, cannot always be retrieved by the call to
+     getStringResource. Therefore set it here if the call fails. */
+  if ((string=getStringResource(windows[MO].widget, "greekFont")) == NULL)
+    string="-adobe-symbol-medium-r-normal--14-*";
   windows[MO].greekFont=makeRasterFont(XtDisplay(windows[MO].widget), string,
                                        &windows[MO].GLgreekFontId);
   if (windows[VIEWER].set >= 0)
