@@ -8,8 +8,11 @@
 *                                                                              *
 ********************************************************************************
 *
-* $Id: input.c,v 1.6 2003/11/07 11:05:02 jrh Exp $
+* $Id: input.c,v 1.7 2004/08/29 14:52:57 jrh Exp $
 * $Log: input.c,v $
+* Revision 1.7  2004/08/29 14:52:57  jrh
+* Release 2.4.1
+*
 * Revision 1.6  2003/11/07 11:05:02  jrh
 * Release 2.4
 *
@@ -450,7 +453,8 @@ int readFile(char *command, char *filename)
       {
         if (strchr(line, '$')) break;
         word=strtok(line, " \t");
-        word=strtok(NULL, " \t");
+	if (strlen(word) < 3)
+          word=strtok(NULL, " \t");
         while ((word=strtok(NULL, " \t")) != NULL)
         {
           mol->cnm[i]=atof(word); 
@@ -1311,6 +1315,7 @@ int moveBasissetData(struct MOLECULE *mol, struct BASISSET *old, int shell, int
   {
     ierror=TRUE;
     p=getStringResource(topShell, "missingBasisset");
+    if (!p) p="The basis set for the atom(s) %s has not been specified.";
     str=(char *)getmem((size_t)(strlen(p)+strlen(missing)+1), sizeof(char));
     sprintf(str, p, missing);
     messgb(topShell, 1, str, buttons, 1);
