@@ -4,12 +4,15 @@
 *                                                                              *
 *                               I N S I N T . C                                *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: insint.c,v 1.5 2000/12/10 15:09:30 jrh Exp $
+* $Id: insint.c,v 1.6 2003/11/07 11:05:10 jrh Exp $
 * $Log: insint.c,v $
+* Revision 1.6  2003/11/07 11:05:10  jrh
+* Release 2.4
+*
 * Revision 1.5  2000/12/10 15:09:30  jrh
 * Release 2.3
 *
@@ -37,6 +40,7 @@ void makeINSIntensity(void)
 {
   struct MOLECULE *mol;
   double pi, h, c, bk, amu, cotfac, qfac;
+  int na;
   register double f, rll, smax;
   register int i, j, k;
 
@@ -55,15 +59,20 @@ void makeINSIntensity(void)
   qfac=h*1.e20/(4.0*pi*pi*c*amu);
 
   smax=0.0;
-  for (i=0; i<3*mol->na; i++)
+  na=0;
+  for (i=0; i<mol->na; i++)
+  {
+    if (mol->atoms[i].flags & ORIGINAL) na++;
+  }
+  for (i=0; i<3*na; i++)
   {
     mol->normal_modes[i].ins_intensity=0.0;
-    if (mol->normal_modes[i].wavenumber > 0.0)
+    if (mol->normal_modes[i].wavenumber > 10.0)
     {
       f=sqrt(qfac/(2.0*mol->normal_modes[i].wavenumber)
        /tanh(cotfac*mol->normal_modes[i].wavenumber));
       k=0;
-      for (j=0; j<mol->na; j++)
+      for (j=0; j<na; j++)
       {
         rll=sqrt(mol->cnm[i+mol->nmodes*k]*mol->cnm[i+mol->nmodes*k]
                 +mol->cnm[i+mol->nmodes*(k+1)]*mol->cnm[i+mol->nmodes*(k+1)]
@@ -76,7 +85,7 @@ void makeINSIntensity(void)
           ? smax : mol->normal_modes[i].ins_intensity;
     }
   }
-  for (i=0; i<3*mol->na; i++)
+  for (i=0; i<3*na; i++)
   {
     if (smax == 0.0)
       mol->normal_modes[i].rel_ins_intensity=0.0;
