@@ -4,12 +4,15 @@
 *                                                                              *
 *                             M A K E T I C S . C                              *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: maketics.c,v 1.5 2000/12/10 15:10:39 jrh Exp $
+* $Id: maketics.c,v 1.6 2003/11/07 11:06:23 jrh Exp $
 * $Log: maketics.c,v $
+* Revision 1.6  2003/11/07 11:06:23  jrh
+* Release 2.4
+*
 * Revision 1.5  2000/12/10 15:10:39  jrh
 * Release 2.3
 *
@@ -28,6 +31,7 @@
 */
 #include<math.h>
 #include<stdio.h>
+#include<stdlib.h>
 
 double dbl_raise(double x, int y)
 {
@@ -41,7 +45,6 @@ double dbl_raise(double x, int y)
   return(val);
 }
 
-
 double makeTics(double tmin, double tmax, double *start, char *format)
 {
   register double r, logr, tic;
