@@ -4,12 +4,15 @@
 *                                                                              *
 *                               M A R C U B . C                                *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: marcub.c,v 1.5 2000/12/10 15:10:52 jrh Exp $
+* $Id: marcub.c,v 1.6 2003/11/07 11:06:36 jrh Exp $
 * $Log: marcub.c,v $
+* Revision 1.6  2003/11/07 11:06:36  jrh
+* Release 2.4
+*
 * Revision 1.5  2000/12/10 15:10:52  jrh
 * Release 2.3
 *
@@ -54,14 +57,17 @@
 #include<stdio.h>
 #include<GL/gl.h>
 #include "marcub.h"
+#include "viewmol.h"
 
 #define FALSE 0
 #define TRUE  1
-#define index(i, j, k) ((ny+1)*(nz+1)*(k)+(nz+1)*(j)+(i))
+#define index(i, j, k) ((grid->ngridpoints[1]+1)*(grid->ngridpoints[2]+1)*(k)+(grid->ngridpoints[2]+1)*(j)+(i))
 
+/* static double norms[27][3], vertices[27][3];
+static int vcount=0, recordit=FALSE; */
 /* Prototypes */
-void set_vertex(double, double, double, int, int, double *, int, int, int,
-                double *, double *, int, void (*)(), void (*)());
+void set_vertex(double, double, double, int, int, struct GRIDOBJECT *, int, int, int,
+                int, void (*)(), void (*)());
 
 /* Global variables */
 static int corner[] = {
@@ -341,59 +347,68 @@ static int count[] = {0,
  3120, 3132, 3142, 3154, 3162, 3168, 3176, 3186, 3196, 3204, 3214, 3222, 3234,
  3240, 3250, 3262, 3270, 3276, 3284, 3290, 3296};
 
-static double cube[8], level, step;
-static int interpol, ny, nz;
+static double cube[8], level;
+static int interpol;
 
-void marchingCube(double xstart, double ystart, double zstart, double grid[],
-                  double gridstep, int xres, int yres, int zres, double surface,
-                  int primitive, void (*begin)(int), void (*end)(void),
+void marchingCube(struct GRIDOBJECT *grid, double surface, int primitive,
+                  void (*begin)(int), void (*end)(void),
                   void (*vert)(double, double, double),
                   void (*norm)(double, double, double), int ip, int debug)
 {
-  double v[3], n[3];
   register double x, y, z;
-  register int i, j, k, l, set, cc;
+  int i, j, k, l, set, cc;
+  register int ii, jj, kk;
 
   level=surface;
   interpol=ip;
-  step=gridstep;
-  ny=yres;
-  nz=zres;
 
-  z=zstart;
-  for (k=0; k<zres; k++)
+/*printf("%f %f %f\n", grid->start[0], grid->start[1], grid->start[2]);
+  printf("%f %f %f\n", grid->step[0], grid->step[1], grid->step[2]);*/
+  for (k=0; k<grid->npoints[2]; k++)
   {
-    y=ystart; 
-    for (j=0; j<yres; j++)
+    kk=k % grid->ngridpoints[2];
+    for (j=0; j<grid->npoints[1]; j++)
     {
-      x=xstart;
-      for (i=0; i<xres; i++)
+      jj=j % grid->ngridpoints[1];
+      for (i=0; i<grid->npoints[0]; i++)
       {
+        ii=i % grid->ngridpoints[0];
         set=0;
-        if (grid[index(i,j,k)]       < level) set|=0x01;
-        if (grid[index(i+1,j,k)]     < level) set|=0x02;
-        if (grid[index(i,j+1,k)]     < level) set|=0x04;
-        if (grid[index(i+1,j+1,k)]   < level) set|=0x08;
-        if (grid[index(i,j,k+1)]     < level) set|=0x10;
-        if (grid[index(i+1,j,k+1)]   < level) set|=0x20;
-        if (grid[index(i,j+1,k+1)]   < level) set|=0x40;
-        if (grid[index(i+1,j+1,k+1)] < level) set|=0x80;
+        if (grid->grid[index(ii,jj,kk)]       < level) set|=0x01;
+        if (grid->grid[index(ii+1,jj,kk)]     < level) set|=0x02;
+        if (grid->grid[index(ii,jj+1,kk)]     < level) set|=0x04;
+        if (grid->grid[index(ii+1,jj+1,kk)]   < level) set|=0x08;
+        if (grid->grid[index(ii,jj,kk+1)]     < level) set|=0x10;
+        if (grid->grid[index(ii+1,jj,kk+1)]   < level) set|=0x20;
+        if (grid->grid[index(ii,jj+1,kk+1)]   < level) set|=0x40;
+        if (grid->grid[index(ii+1,jj+1,kk+1)] < level) set|=0x80;
 
-        if (set == 0 || set == 255)
-        {
-          x+=step;
-          continue;
-        }
-
-        cube[0]=grid[index(i,j,k)];
-        cube[1]=grid[index(i+1,j,k)];
-        cube[2]=grid[index(i+1,j+1,k)];
-        cube[3]=grid[index(i,j+1,k)];
-        cube[4]=grid[index(i,j,k+1)];
-        cube[5]=grid[index(i+1,j,k+1)];
-        cube[6]=grid[index(i+1,j+1,k+1)];
-        cube[7]=grid[index(i,j+1,k+1)];
+        if (set == 0 || set == 255) continue;
 
+        cube[0]=grid->grid[index(ii,jj,kk)];
+        cube[1]=grid->grid[index(ii+1,jj,kk)];
+        cube[2]=grid->grid[index(ii+1,jj+1,kk)];
+        cube[3]=grid->grid[index(ii,jj+1,kk)];
+        cube[4]=grid->grid[index(ii,jj,kk+1)];
+        cube[5]=grid->grid[index(ii+1,jj,kk+1)];
+        cube[6]=grid->grid[index(ii+1,jj+1,kk+1)];
+        cube[7]=grid->grid[index(ii,jj+1,kk+1)];
+  
+        x=grid->vector1[0]*(double)i*grid->step[0]
+         +grid->vector2[0]*(double)j*grid->step[1]
+         +grid->vector3[0]*(double)k*grid->step[2]+grid->start[0];
+        y=grid->vector1[1]*(double)i*grid->step[0]
+         +grid->vector2[1]*(double)j*grid->step[1]
+         +grid->vector3[1]*(double)k*grid->step[2]+grid->start[1];
+        z=grid->vector1[2]*(double)i*grid->step[0]
+         +grid->vector2[2]*(double)j*grid->step[1]
+         +grid->vector3[2]*(double)k*grid->step[2]+grid->start[2];
+/*
+        glColor4f(0.0, 0.0, 0.0, 0.0);
+        glBegin(GL_POINTS);
+        glVertex3d(x, y, z);
+        glEnd();
+*/
         if (primitive == GL_TRIANGLE_STRIP)
         {
           (*begin)(primitive);
@@ -401,13 +416,13 @@ void marchingCube(double xstart, double ystart, double zstart, double grid[],
           {
             if (corner[l] == -1)
             {
-                (*end)();
+              (*end)();
               (*begin)(primitive);
               l--;
             }
             else
-              set_vertex(x, y, z, corner[l], corner[l+1], grid, i, j, k,
-                             v, n, primitive, vert, norm);
+              set_vertex(x, y, z, corner[l], corner[l+1], grid, ii, jj, kk,
+                         primitive, vert, norm);
           }
           (*end)();
         }
@@ -422,31 +437,28 @@ void marchingCube(double xstart, double ystart, double zstart, double grid[],
               l++;
             }
             if (cc == 0 || cc > 2) (*begin)(primitive);
-            set_vertex(x, y, z, corner[l], corner[l+1], grid, i, j, k,
-                       v, n, primitive, vert, norm);
+            set_vertex(x, y, z, corner[l], corner[l+1], grid, ii, jj, kk,
+                       primitive, vert, norm);
             cc++;
             if (cc > 3)
             {
-              set_vertex(x, y, z, corner[l-2], corner[l-1], grid, i, j, k,
-                         v, n, primitive, vert, norm);
-              set_vertex(x, y, z, corner[l-4], corner[l-3], grid, i, j, k,
-                         v, n, primitive, vert, norm);
+              set_vertex(x, y, z, corner[l-2], corner[l-1], grid, ii, jj, kk,
+                         primitive, vert, norm);
+              set_vertex(x, y, z, corner[l-4], corner[l-3], grid, ii, jj, kk,
+                         primitive, vert, norm);
               cc+=2;
             }
             if (cc % 3 == 0) (*end)();
           }
         }
-        x+=step;
       }
-      y+=step;
     }
-    z+=step;
   }
 }
 
-void set_vertex(double x, double y, double z, int c1, int c2, double grid[],
-                int ig, int jg, int kg, double *v, double *n, int primitive,
-                void (*vert)(double, double, double), void (*norm)(double, double, double))
+void set_vertex(double x, double y, double z, int c1, int c2, struct GRIDOBJECT *grid,
+                int ig, int jg, int kg, int primitive, void (*vert)(double, double, double),
+                void (*norm)(double, double, double))
 {
   static double vertex[8][8][3]={{{0.0, 0.0, 0.0}, {0.5, 0.0, 0.0},
                                   {0.0, 0.0, 0.0}, {0.0, 0.5, 0.0},
@@ -481,36 +493,15 @@ void set_vertex(double x, double y, double z, int c1, int c2, double grid[],
                                   {0.0, -0.5, 1.0}, {0.0, 0.0, 0.0},
                                   {0.5, 1.0, 1.0}, {0.0, 0.0, 0.0}},
                                   };
-  double x1=cube[c1], x2=cube[c2], l=level;
-  register int i ;
+  double v[3], x1=cube[c1], x2=cube[c2], l=level, n1[3], n2[3];
+  int ii, jj, kk;
+  register int i;
  
-  switch (c1)
-  {
-    case 1: ig++;
-            break;
-    case 2: ig++;
-            jg++;
-            break;
-    case 3: jg++;
-            break;
-    case 4: kg++;
-            break;
-    case 5: ig++;
-            kg++;
-            break;
-    case 6: ig++;
-            jg++;
-            kg++;
-            break;
-    case 7: jg++;
-            kg++;
-            break;
-  }
   switch (interpol)
   {
-    case IP_NONE:   v[0]=x+fabs(vertex[c1][c2][0])*step;
-                    v[1]=y+fabs(vertex[c1][c2][1])*step;
-                    v[2]=z+fabs(vertex[c1][c2][2])*step;
+    case IP_NONE:   v[0]=fabs(vertex[c1][c2][0]);
+                    v[1]=fabs(vertex[c1][c2][1]);
+                    v[2]=fabs(vertex[c1][c2][2]);
                     break;
     case IP_LOG:    if (x1 > 0.0) x1=log(x1);
                     if (x2 > 0.0) x2=log(x2);
@@ -520,27 +511,170 @@ void set_vertex(double x, double y, double z, int c1, int c2, double grid[],
                     for (i=0; i<3; i++)
                     {
                       v[i]=vertex[c1][c2][i];
-                      if (v[i] == 0.5e0) v[i]=fabs(x1)/(fabs(x1)+fabs(x2));
-                      if (v[i] == -0.5e0) v[i]=1.0-fabs(x1)/(fabs(x1)+fabs(x2));
+                      if (v[i] ==  0.5) v[i]=fabs(x1)/(fabs(x1)+fabs(x2));
+                      if (v[i] == -0.5) v[i]=1.0-fabs(x1)/(fabs(x1)+fabs(x2));
                     }
-                    v[0]=x+v[0]*step;
-                    v[1]=y+v[1]*step;
-                    v[2]=z+v[2]*step;
                     break;
   }
   if (primitive == GL_TRIANGLE_STRIP)
   {
-/*  if (ig < gridres) */
-      n[0]=v[0]+(grid[index(ig-1, jg, kg)]-grid[index(ig+1, jg, kg)])/(2.0*step);
-/*  if (jg < gridres) */
-      n[1]=v[1]+(grid[index(ig, jg-1, kg)]-grid[index(ig, jg+1, kg)])/(2.0*step);
-/*  if (kg < gridres) */
-      n[2]=v[2]+(grid[index(ig, jg, kg-1)]-grid[index(ig, jg, kg+1)])/(2.0*step);
-    l=sqrt(n[0]*n[0]+n[1]*n[1]+n[2]*n[2]);
-    n[0]/=l;
-    n[1]/=l;
-    n[2]/=l;
-    (*norm)(n[0], n[1], n[2]);
+    ii=ig;
+    jj=jg;
+    kk=kg;
+    switch (c1)
+    {
+      case 1: ii++;
+              break;
+      case 2: ii++;
+              jj++;
+              break;
+      case 3: jj++;
+              break;
+      case 4: kk++;
+              break;
+      case 5: ii++;
+              kk++;
+              break;
+      case 6: ii++;
+              jj++;
+              kk++;
+              break;
+      case 7: jj++;
+              kk++;
+              break;
+    }
+    if (ii >= grid->ngridpoints[0]-1)
+      n1[0]=(grid->grid[index(ii-1, jj, kk)]-grid->grid[index(ii, jj, kk)])/grid->step[0];
+    else if (ii == 0)
+      n1[0]=(grid->grid[index(ii+1, jj, kk)]-grid->grid[index(ii, jj, kk)])/grid->step[0];
+    else
+      n1[0]=(grid->grid[index(ii-1, jj, kk)]-grid->grid[index(ii+1, jj, kk)])/(2.0*grid->step[0]);
+    if (jj >= grid->ngridpoints[1]-1)
+      n1[1]=(grid->grid[index(ii, jj-1, kk)]-grid->grid[index(ii, jj, kk)])/grid->step[1];
+    else if (jj == 0)
+      n1[1]=(grid->grid[index(ii, jj+1, kk)]-grid->grid[index(ii, jj, kk)])/grid->step[1];
+    else
+      n1[1]=(grid->grid[index(ii, jj-1, kk)]-grid->grid[index(ii, jj+1, kk)])/(2.0*grid->step[1]);
+    if (kk >= grid->ngridpoints[2]-1)
+      n1[2]=(grid->grid[index(ii, jj, kk-1)]-grid->grid[index(ii, jj, kk)])/grid->step[2];
+    else if (kk == 0)
+      n1[2]=(grid->grid[index(ii, jj, kk+1)]-grid->grid[index(ii, jj, kk)])/grid->step[2];
+    else
+      n1[2]=(grid->grid[index(ii, jj, kk-1)]-grid->grid[index(ii, jj, kk+1)])/(2.0*grid->step[2]);
+    ii=ig;
+    jj=jg;
+    kk=kg;
+    switch (c2)
+    {
+      case 1: ii++;
+              break;
+      case 2: ii++;
+              jj++;
+              break;
+      case 3: jj++;
+              break;
+      case 4: kk++;
+              break;
+      case 5: ii++;
+              kk++;
+              break;
+      case 6: ii++;
+              jj++;
+              kk++;
+              break;
+      case 7: jj++;
+              kk++;
+              break;
+    }
+    if (ii >= grid->ngridpoints[0]-1)
+      n2[0]=(grid->grid[index(ii-1, jj, kk)]-grid->grid[index(ii, jj, kk)])/grid->step[0];
+    else if (ii == 0)
+      n2[0]=(grid->grid[index(ii+1, jj, kk)]-grid->grid[index(ii, jj, kk)])/grid->step[0];
+    else
+      n2[0]=(grid->grid[index(ii-1, jj, kk)]-grid->grid[index(ii+1, jj, kk)])/(2.0*grid->step[0]);
+    if (jj >= grid->ngridpoints[1]-1)
+      n2[1]=(grid->grid[index(ii, jj-1, kk)]-grid->grid[index(ii, jj, kk)])/grid->step[1];
+    else if (jj == 0)
+      n2[1]=(grid->grid[index(ii, jj+1, kk)]-grid->grid[index(ii, jj, kk)])/grid->step[1];
+    else
+      n2[1]=(grid->grid[index(ii, jj-1, kk)]-grid->grid[index(ii, jj+1, kk)])/(2.0*grid->step[1]);
+    if (kk >= grid->ngridpoints[2]-1)
+      n2[2]=(grid->grid[index(ii, jj, kk-1)]-grid->grid[index(ii, jj, kk)])/grid->step[2];
+    else if (kk == 0)
+      n2[2]=(grid->grid[index(ii, jj, kk+1)]-grid->grid[index(ii, jj, kk)])/grid->step[2];
+    else
+      n2[2]=(grid->grid[index(ii, jj, kk-1)]-grid->grid[index(ii, jj, kk+1)])/(2.0*grid->step[2]);
+    n1[0]=0.5*(n1[0]+n2[0]);
+    n1[1]=0.5*(n1[1]+n2[1]);
+    n1[2]=0.5*(n1[2]+n2[2]);
+    if (level > 0.0)
+      l=sqrt(n1[0]*n1[0]+n1[1]*n1[1]+n1[2]*n1[2]);
+    else
+      l=-sqrt(n1[0]*n1[0]+n1[1]*n1[1]+n1[2]*n1[2]);
+    n1[0]/=l;
+    n1[1]/=l;
+    n1[2]/=l;
+    (*norm)(n1[0], n1[1], n1[2]);
   }
+/*recordit=TRUE; */
+  v[0]=x+v[0]*grid->vector1[0]*grid->step[0]
+      +v[1]*grid->vector2[0]*grid->step[1]
+      +v[2]*grid->vector3[0]*grid->step[2];
+  v[1]=y+v[0]*grid->vector1[1]*grid->step[0]
+      +v[1]*grid->vector2[1]*grid->step[1]
+      +v[2]*grid->vector3[1]*grid->step[2];
+  v[2]=z+v[0]*grid->vector1[2]*grid->step[0]
+      +v[1]*grid->vector2[2]*grid->step[1]
+      +v[2]*grid->vector3[2]*grid->step[2];
   (*vert)(v[0], v[1], v[2]);
+/*printf("%f %f %f %f %f %f\n", v[0], v[1], v[2], n1[0], n1[1], n1[2]); */
 }
+/*
+void testNorm(double x, double y, double z)
+{
+  norms[vcount][0]=0.2*x;
+  norms[vcount][1]=0.2*y;
+  norms[vcount][2]=0.2*z;
+  glNormal3d(x, y, z);
+}
+
+void testVertex(double x, double y, double z)
+{
+  if (recordit)
+  {
+    vertices[vcount][0]=x;
+    vertices[vcount][1]=y;
+    vertices[vcount][2]=z;
+    vcount++;
+  }
+  glVertex3d(x, y, z);
+}
+
+void testBegin(GLenum what)
+{
+  vcount=0;
+  glBegin(what);
+}
+
+void testEnd(void)
+{
+  int i;
+
+  glEnd();
+  if (recordit)
+  {
+    for (i=0; i<vcount; i++)
+    {
+      glColor4f(0.0, 0.0, 0.0, 0.5);
+      glBegin(GL_LINES);
+      glVertex3d(vertices[i][0], vertices[i][1], vertices[i][2]);
+      glVertex3d(vertices[i][0]+norms[i][0], vertices[i][1]+norms[i][1], vertices[i][2]+norms[i][2]);
+      glEnd();
+      if (level > 0.0)
+        glColor4f(1.0, 0.0, 0.0, 0.0);
+      else
+        glColor4f(0.0, 0.0, 1.0, 0.0);
+    }
+    recordit=FALSE;
+  }
+} */
