@@ -8,8 +8,11 @@
 *                                                                              *
 ********************************************************************************
 *
-* $Id: matrix.c,v 1.5 2003/11/07 11:06:42 jrh Exp $
+* $Id: matrix.c,v 1.6 2004/08/29 14:54:32 jrh Exp $
 * $Log: matrix.c,v $
+* Revision 1.6  2004/08/29 14:54:32  jrh
+* Release 2.4.1
+*
 * Revision 1.5  2003/11/07 11:06:42  jrh
 * Release 2.4
 *
@@ -30,6 +33,7 @@
 #include<stdio.h>
 #include<GL/gl.h>
 #include<GL/glu.h>
+#include<X11/StringDefs.h>
 #include "viewmol.h"
 
 extern void quaternionToMatrix(GLenum, float *);
@@ -88,13 +92,7 @@ void transformCoordinates(int which, float input[4], float output[4])
 
   glPushMatrix();
   glLoadIdentity();
-  switch (which)
-  {
-    case VIEWPOINT: quaternionToMatrix(GL_PROJECTION, &rotObject[4*which]);
-                    break;
-    default:        quaternionToMatrix(GL_MODELVIEW, &rotObject[4*which]);
-                    break;
-  }
+  quaternionToMatrix(GL_MODELVIEW, &rotObject[4*which]);
   glGetFloatv(GL_MODELVIEW_MATRIX, &matrix[0][0]);
   glPopMatrix();
 
