@@ -4,12 +4,15 @@
 *                                                                              *
 *                               M E S S G B . C                                *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: messgb.c,v 1.5 2000/12/10 15:11:26 jrh Exp $
+* $Id: messgb.c,v 1.6 2003/11/07 11:06:50 jrh Exp $
 * $Log: messgb.c,v $
+* Revision 1.6  2003/11/07 11:06:50  jrh
+* Release 2.4
+*
 * Revision 1.5  2000/12/10 15:11:26  jrh
 * Release 2.3
 *
@@ -140,7 +143,7 @@ int messgb(Widget parent, int serious, char *str,
     XtVaGetValues(form1, XmNforeground, &fg, XmNbackground, &bg, NULL);
     XtVaGetValues(parent, XtNdepth, &depth, NULL);
     pixmap=XCreatePixmapFromBitmapData(XtDisplay(form1), RootWindowOfScreen(XtScreen(form1)),
-                                       sign_data[serious-1], 64, 64, fg, bg, depth);
+                                       (char *)sign_data[serious-1], 64, 64, fg, bg, depth);
     sign=XtVaCreateManagedWidget("sign", xmLabelWidgetClass, form1,
                                   XmNlabelType, XmPIXMAP,
                                   XmNlabelPixmap, pixmap,
