@@ -8,8 +8,11 @@
 *                                                                              *
 ********************************************************************************
 *
-* $Id: mkunitc.c,v 1.6 2003/11/07 11:07:10 jrh Exp $
+* $Id: mkunitc.c,v 1.7 2004/08/29 14:56:58 jrh Exp $
 * $Log: mkunitc.c,v $
+* Revision 1.7  2004/08/29 14:56:58  jrh
+* Release 2.4.1
+*
 * Revision 1.6  2003/11/07 11:07:10  jrh
 * Release 2.4
 *
@@ -39,7 +42,7 @@ void fractionalToCartesian(struct ATOM *, double, double, double, double,
                            double, double, struct MOLECULE *, int, int);
 double *cartesianToFractional(double, double, double, double, double, double,
                               double *, double *, double *, int *, int);
-void expandCell(int);
+void expandCell(int, int);
 void addBoundaryAtoms(struct MOLECULE *);
 void shiftUnitCell(struct MOLECULE *);
 
@@ -248,21 +251,6 @@ void fractionalToCartesian(struct ATOM *atoms, double a, double b, double c,
     for (i=0; i<mol->nhist; i++)
     {
       k=i*to;
-/*    a=dist(mol->history[k+to].x, mol->history[k+to].y, mol->history[k+to].z,
-             mol->history[k+to+1].x, mol->history[k+to+1].y, mol->history[k+to+1].z);
-      b=dist(mol->history[k+to].x, mol->history[k+to].y, mol->history[k+to].z,
-             mol->history[k+to+2].x, mol->history[k+to+2].y, mol->history[k+to+2].z);
-      c=dist(mol->history[k+to].x, mol->history[k+to].y, mol->history[k+to].z,
-             mol->history[k+to+3].x, mol->history[k+to+3].y, mol->history[k+to+3].z);
-      alpha=torad*angle(mol->history[k+to+2].x, mol->history[k+to+2].y, mol->history[k+to+2].z,
-                        mol->history[k+to].x, mol->history[k+to].y, mol->history[k+to].z,
-                        mol->history[k+to+3].x, mol->history[k+to+3].y, mol->history[k+to+3].z);
-      beta=torad*angle(mol->history[k+to+1].x, mol->history[k+to+1].y, mol->history[k+to+1].z,
-                       mol->history[k+to].x, mol->history[k+to].y, mol->history[k+to].z,
-                       mol->history[k+to+3].x, mol->history[k+to+3].y, mol->history[k+to+3].z);
-      gamma=torad*angle(mol->history[k+to+1].x, mol->history[k+to+1].y, mol->history[k+to+1].z,
-                        mol->history[k+to].x, mol->history[k+to].y, mol->history[k+to].z,
-                        mol->history[k+to+2].x, mol->history[k+to+2].y, mol->history[k+to+2].z); */
       x2=mol->unitcell->b*cos(mol->unitcell->gamma);
       y2=sqrt(mol->unitcell->b*mol->unitcell->b-x2*x2);
       x3=mol->unitcell->c*cos(mol->unitcell->beta);
@@ -296,7 +284,6 @@ double *cartesianToFractional(double a, double b, double c, double alpha,
     mol=&molecules[windows[VIEWER].set];
   else
     mol=&molecules[0];
-/*printf("%f %f %f\n", a, b, c);*/
   torad=atan(1.0)/45.0;
   alpha*=torad;
   beta*=torad;
@@ -334,7 +321,6 @@ double *cartesianToFractional(double a, double b, double c, double alpha,
       if (*xmin < 0.0) frac[j]  -=(*xmin);
       if (*ymin < 0.0) frac[j+1]-=(*ymin);
       if (*zmin < 0.0) frac[j+2]-=(*zmin);
-/*printf("%f %f %f\n", frac[j], frac[j+1], frac[j+2]);*/
       j+=3;
     }
   }
@@ -342,7 +328,7 @@ double *cartesianToFractional(double a, double b, double c, double alpha,
   return(frac);
 }
 
-void expandCell(int doConnectivity)
+void expandCell(int doConnectivity, int setWindow)
 {
   struct NEW
   {
@@ -388,7 +374,7 @@ void expandCell(int doConnectivity)
           if (new[nnew].x <= mol->unitcell->factor[0] &&
               new[nnew].y <= mol->unitcell->factor[1] &&
               new[nnew].z <= mol->unitcell->factor[2])
-          new[nnew++].ref=m;
+            new[nnew++].ref=m;
         }
       }
     }
@@ -427,7 +413,10 @@ void expandCell(int doConnectivity)
   {
     addBoundaryAtoms(mol);
     a=forceScale;
-    makeConnectivity(mol, TRUE, TRUE);
+    /* setWindow should not be TRUE if expandCell
+       is called due to the user moving to a
+       different frame in the optimization history */
+    makeConnectivity(mol, setWindow, TRUE);
     forceScale=a;
   }
   if (mol->unitcell->nmiller != 0) millerPlane();
@@ -454,12 +443,15 @@ void addBoundaryAtoms(struct MOLECULE *mol)
   mol->unitcell->factor[0]+=THRESHOLD;
   mol->unitcell->factor[1]+=THRESHOLD;
   mol->unitcell->factor[2]+=THRESHOLD;
-  expandCell(FALSE);
+  expandCell(FALSE, FALSE);
   mol->unitcell->factor[0]=cellFactor[0];
   mol->unitcell->factor[1]=cellFactor[1];
   mol->unitcell->factor[2]=cellFactor[2];
   for (i=nlast; i<mol->na; i++)
+  {
     mol->atoms[i].flags|=DISPLAY_ONLY;
+/*  printf("%f %f %f %s\n", mol->atoms[i].x, mol->atoms[i].y, mol->atoms[i].z, mol->atoms[i].name);*/
+  }
 }
 
 void shiftUnitCell(struct MOLECULE *mol)
