@@ -8,8 +8,11 @@
 *                                                                              *
 ********************************************************************************
 *
-* $Id: moleculemodule.c,v 1.2 2003/11/07 11:07:39 jrh Exp $
+* $Id: moleculemodule.c,v 1.3 2004/08/29 14:57:28 jrh Exp $
 * $Log: moleculemodule.c,v $
+* Revision 1.3  2004/08/29 14:57:28  jrh
+* Release 2.4.1
+*
 * Revision 1.2  2003/11/07 11:07:39  jrh
 * Release 2.4
 *
@@ -89,7 +92,7 @@ extern void redraw(int);
 extern void bfnamn(int, int *, int*);
 extern void annotateWavefunction(void);
 extern void buildMolecule(struct MOLECULE *, int, int, int);
-extern void expandCell(int);
+extern void expandCell(int, int);
 extern void millerPlane(void);
 extern int checkInterrupt(void);
 extern void newMolecule(Widget, caddr_t, XmAnyCallbackStruct *);
@@ -899,7 +902,7 @@ static PyObject *molecule_unitCell(PyObject *self, PyObject *args)
      mol->unitcell->factor[0]=xfac;
      mol->unitcell->factor[1]=yfac;
      mol->unitcell->factor[2]=zfac;
-     expandCell(TRUE);
+     expandCell(TRUE, TRUE);
   }
   Py_INCREF(Py_None);
   return(Py_None);
