@@ -8,8 +8,11 @@
 *                                                                              *
 ********************************************************************************
 *
-* $Id: mouseaction.c,v 1.6 2003/11/07 11:07:48 jrh Exp $
+* $Id: mouseaction.c,v 1.7 2004/08/29 14:58:01 jrh Exp $
 * $Log: mouseaction.c,v $
+* Revision 1.7  2004/08/29 14:58:01  jrh
+* Release 2.4.1
+*
 * Revision 1.6  2003/11/07 11:07:48  jrh
 * Release 2.4
 *
@@ -92,7 +95,6 @@ extern int  makeAnnotation(int, int, float, float, float, int, const GLfloat *,
 extern void deleteAnnotation(int *);
 extern void annotateWavefunction(void);
 extern void modifyAnnotation(int, int, int);
-extern void transformCoordinates(int, float input[4], float output[4]);
 extern void setWindowTitle(Widget, char *);
 extern void buildMolecule(struct MOLECULE *, int, int, int);
 extern void setupProjection(int);
@@ -102,7 +104,7 @@ extern Widget makeViewerMenu(Widget);
 extern int checkZoom(int);
 extern void setMenu(struct MOLECULE *);
 extern void updateMOs(int);
-extern void expandCell(int);
+extern void expandCell(int, int);
 extern void getScreenCoordinates(double, double, double, double *, double *,
                                  double *);
 extern void getWorldCoordinates(double, double, double, double *, double *,
@@ -911,7 +913,7 @@ void setGeometry(int doConnectivity)
       mol->unitcell[0].corners[j].y=mol->unitcell[i].corners[j].y;
       mol->unitcell[0].corners[j].z=mol->unitcell[i].corners[j].z;
     }
-    expandCell(TRUE);
+    expandCell(TRUE, FALSE);
   }
   word=getStringResource(topShell, "historyTitle");
 /*sprintf(line, word, (int)mol->cycle, mol->optimization[(int)mol->cycle-1].energy,
