@@ -4,12 +4,15 @@
 *                                                                              *
 *                             O P T I F O R M . C                              *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: optiform.c,v 1.5 2000/12/10 15:13:26 jrh Exp $
+* $Id: optiform.c,v 1.6 2003/11/07 11:08:11 jrh Exp $
 * $Log: optiform.c,v $
+* Revision 1.6  2003/11/07 11:08:11  jrh
+* Release 2.4
+*
 * Revision 1.5  2000/12/10 15:13:26  jrh
 * Release 2.3
 *
@@ -82,7 +85,7 @@ void optimizationDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
   sep=XtVaCreateManagedWidget("sep", xmSeparatorWidgetClass, form, NULL);
 
   checkbox=CreateToggleBox(form1, checkbox_buttons, XtNumber(checkbox_buttons),
-                           XmVERTICAL, 1, False, windows[HISTORY].mode & 0x3);
+                           XmVERTICAL, 1, False, (windows[HISTORY].mode & 0x3));
   XtVaSetValues(checkbox, XmNleftAttachment, XmATTACH_FORM,
                           XmNrightAttachment, XmATTACH_FORM,
                           XmNtopAttachment, XmATTACH_FORM,
