@@ -130,7 +130,7 @@ void printDialog(Widget widget, caddr_t which, XmAnyCallbackStruct *data)
     { "lzw", &xmPushButtonGadgetClass, GetCompression, (XtPointer)COMPRESSION_LZW, NULL, NULL },
     { NULL, NULL, NULL, NULL, NULL, NULL }
   };
-  char line[MAXLENLINE];
+  char line[MAXLENLINE], *word;
   int imol;
   register int i;
 
@@ -213,7 +213,8 @@ void printDialog(Widget widget, caddr_t which, XmAnyCallbackStruct *data)
                                  XmNtopAttachment, XmATTACH_WIDGET,
                                  XmNtopWidget, sep2,
                                  NULL);
-  if (strcmp(getStringResource(topShell, "hasLZW"), "True"))
+  word=getStringResource(topShell, "hasLZW");
+  if (word && strcmp(word, "True"))
     compressionMenu[2].label=NULL;
   comp=makeMenu(form2, XmMENU_OPTION, "compression", compressionMenu);
   if (format == TIFFFILE)
