@@ -8,8 +8,11 @@
 *                                                                              *
 ********************************************************************************
 *
-* $Id: readframe.c,v 1.5 2003/11/07 11:13:18 jrh Exp $
+* $Id: readframe.c,v 1.6 2004/08/29 15:00:33 jrh Exp $
 * $Log: readframe.c,v $
+* Revision 1.6  2004/08/29 15:00:33  jrh
+* Release 2.4.1
+*
 * Revision 1.5  2003/11/07 11:13:18  jrh
 * Release 2.4
 *
@@ -31,7 +34,7 @@
 #include<stdlib.h>
 #include<string.h>
 
-#define MAXLENLINE 82
+#define MAXLENLINE 84
 #define FALSE 0
 #define TRUE  1
 
@@ -77,20 +80,23 @@ int readFrame(FILE *mainfile, int pbc, int first, double conv, int version,
   {
     if (strstr(line, "end") == NULL && line[0] != '!')
     {
-	if (strstr(line, "PBC") == &line[0])
-	{
+      if (strstr(line, "PBC") == &line[0])
+      {
         if (first)
+        {
           printf("$unitcell %s\n", strtok(line, "(")+3);
+	  printf("$symmetry %s\n", strtok(NULL, ")"));
+        }
         else
           printf("  unitcell %s\n", strtok(line, "(")+3);
-	}
-	else
-	{
-	  if (first && na == 0)
-	  {
+      }
+      else
+      {
+        if (first && na == 0)
+        {
           printf("$coord %12.8f\n", conv);
           conv=(double)1.0/conv;
-	  }
+        }
         word=strtok(line+6, " \t");
         printf("%22.14f ", conv*atof(word));
         if (strlen(word) > 15)
@@ -112,16 +118,16 @@ int readFrame(FILE *mainfile, int pbc, int first, double conv, int version,
         word=strtok(NULL, " \t");
         word=strtok(NULL, " \t");
         word=strtok(NULL, " \t");
-	  if (version < 2)
+        if (version < 2)
           printf("%s\n", word);
-	  else
-	  {
+        else
+        {
           word=strtok(NULL, " \t");
           printf("%s\n", word);
-  	  }
+        }
         if (realEnd) realEnd=FALSE;
         na++;
-	}
+      }
     }
     else
     {
