@@ -8,8 +8,11 @@
 *                                                                              *
 ********************************************************************************
 *
-* $Id: readgauss.c,v 1.6 2003/11/07 11:13:35 jrh Exp $
+* $Id: readgauss.c,v 1.7 2004/07/04 15:28:50 jrh Exp $
 * $Log: readgauss.c,v $
+* Revision 1.7  2004/07/04 15:28:50  jrh
+* Updated for Gaussian03
+*
 * Revision 1.6  2003/11/07 11:13:35  jrh
 * Release 2.4
 *
@@ -52,6 +55,7 @@
 #define INPOR "input orientation:"
 #define GAUSS1 "entering gaussian system"
 #define GAUSS2 "entering link 1 ="
+#define GAUSSIAN03 "This is the Gaussian(R) 03 program."
 #define XCOORD "x-coord"
 #define OSYM "orbital symmetries"
 #define AMOS "alpha mos:"
@@ -65,7 +69,7 @@
 int  main(int, char **);
 void readBasis(FILE *, int);
 void readMOs(int, FILE *);
-void readFrq(FILE *, int, int);
+void readFrq(FILE *, int, int, int);
 int  readOpg(FILE *, int, int, char *, char *);
 void printCoord(double **, char **, int);
 double reade(char *, char *, int *);
@@ -88,6 +92,7 @@ int main(int argc, char **argv)
   int nemark=0, nout, na, ncent, nuc;
   int mna=50, cycle=0;
   int etex;
+  int version = 98;
   register double x, y, z;
   register int i, mak;
 
@@ -100,6 +105,13 @@ int main(int argc, char **argv)
     if (fgets(line, MAXLENLINE, file) == NULL) eof("wrongFiletype", argv[1], 1);
     makeLower(line);
   } while (!(strstr(line, GAUSS1) || strstr(line, GAUSS2)));
+
+  for (i=0; i<10; i++)  /* test for Gaussian03 */
+  {
+    if (fgets(line, MAXLENLINE, file) == NULL) eof("wrongFiletype", argv[1], 1);
+    if (strstr(line, GAUSSIAN03)) version=3;
+  }
+
   do
   {
     if (fgets(line, MAXLENLINE, file) == NULL) eof("noCoordinates", argv[1], 1);
@@ -229,7 +241,7 @@ int main(int argc, char **argv)
     y=atof(strtok(NULL, " \t\n"));
     z=atof(strtok(NULL, " \t\n"));
 
-    if (nuc >= 0)                            /* nur bei Z-ori ! */
+    if (nuc >= 0)                            /* only for Z-ori ! */
     {
       symbol[3*na]=pse[nuc][0];
       symbol[3*na+1]=pse[nuc][1];
@@ -250,7 +262,6 @@ int main(int argc, char **argv)
   }
 
 /* Load optimization history */
-
   if (opt) cycle=readOpg(file, na, nemark, &emark[0][0], orientation);
 
 /* Load basis functions */
@@ -267,9 +278,9 @@ int main(int argc, char **argv)
   }
 
 /* Load total energy */
-
   if (!opt)
   {
+    rewind(file);
     do
     {
       if (fgets(line, MAXLENLINE, file) == NULL) eof("noEnergy", argv[1], 0);
@@ -296,7 +307,7 @@ int main(int argc, char **argv)
 
 /* Load frequencies and normal modes vectors */
 
-  if (freq) readFrq(file, na, nout);
+  if (freq) readFrq(file, na, nout, version);
 
   printf("$end\n");
   fclose(file);
@@ -614,7 +625,7 @@ void readMOs(int cycle, FILE *file)
   fremem((void **)&cmo);
 }
 
-void readFrq(FILE *file, int na, int nout)
+void readFrq(FILE *file, int na, int nout, int version)
 {
   static int first=TRUE;
   double *freq, *ir, *raman, *nmo;
@@ -636,10 +647,14 @@ void readFrq(FILE *file, int na, int nout)
   symmod=(char *)getmem(ncart, 4*sizeof(char));
   nmo=(double *)getmem(ncart*(ncart+nout), sizeof(double));
 
-  fgets(line, MAXLENLINE, file);
-  fgets(line, MAXLENLINE, file);
+  do
+  {
+    fgets(line, MAXLENLINE, file);
+  }
+  while (!strstr(line, ":"));
   while (nfrq < ncart)
   {
+
     fgets(line, MAXLENLINE, file);
     fgets(line, MAXLENLINE, file);
     strcpy(&symmod[4*nfrq], strtok(line, " \t\n"));
@@ -667,14 +682,18 @@ void readFrq(FILE *file, int na, int nout)
       ir[i]=atof(strtok(NULL, " \t"));
 
     fgets(line, MAXLENLINE, file);
-    strtok(line, " \t");
-    strtok(NULL, " \t");
-    strtok(NULL, " \t");
-    for (i=nfrq; i<end; i++)
-      raman[i]=atof(strtok(NULL, " \t"));
-
-    fgets(line, MAXLENLINE, file);
-    fgets(line, MAXLENLINE, file);
+    if (strstr(line, "Raman"))
+    {
+      strtok(line, " \t");
+      strtok(NULL, " \t");
+      strtok(NULL, " \t");
+      for (i=nfrq; i<end; i++)
+        raman[i]=atof(strtok(NULL, " \t"));
+      fgets(line, MAXLENLINE, file);
+      fgets(line, MAXLENLINE, file);
+      if (version == 3) fgets(line, MAXLENLINE, file);  /* skip additional "Depolar" for Gaussian03 */
+    }
+    printf("%s", line);
     makeLower(line);
     if (strstr(line, "x      y      z"))
     {
