@@ -8,8 +8,11 @@
 *                                                                              *
 ********************************************************************************
 *
-* $Id: readmopac.c,v 1.4 2003/11/07 11:14:38 jrh Exp $
+* $Id: readmopac.c,v 1.5 2004/08/29 15:01:27 jrh Exp $
 * $Log: readmopac.c,v $
+* Revision 1.5  2004/08/29 15:01:27  jrh
+* Release 2.4.1
+*
 * Revision 1.4  2003/11/07 11:14:38  jrh
 * Release 2.4
 *
@@ -23,6 +26,7 @@
 * Initial revision
 *
 */
+#include<ctype.h>
 #include<stdlib.h>
 #include<stdio.h>
 #include<string.h>
@@ -40,6 +44,7 @@ int swapInt(int *);
 double swapDouble(double *);
 int passInt(int *);
 double passDouble(double *);
+void makeLower(char *line);
 
 extern void *getmem(size_t, size_t);
 extern void *expmem(void *, size_t, size_t);
@@ -55,6 +60,7 @@ int main(int argc, char **argv)
   int (*getInt)(int *);
   int *ip, dof=0, last, count=0, hasSymLabels=FALSE;
   int numat=0, norbs=0, nelecs=0, *nfirst=NULL, *nlast, *nat;
+  int isVamp=FALSE;
   char line[MAXLENLINE], f[MAXLENLINE], *word, *buffer, *sym=NULL;
   register int i=0, j, k;
 
@@ -157,11 +163,14 @@ int main(int argc, char **argv)
 
   while (fgets(line, MAXLENLINE, file) != NULL)
   {
-    if (strstr(line, "CARTESIAN COORDINATES") && coord == NULL)
+    makeLower(line);
+    if (strstr(line, "cartesian coordinates") && coord == NULL)
     {
+      if (strstr(line, "<>")) fgets(line, MAXLENLINE, file);
       fgets(line, MAXLENLINE, file);
       fgets(line, MAXLENLINE, file);
-      if (strstr(line, "NO.       ATOM               X         Y         Z"))
+      makeLower(line);
+      if (strstr(line, "no.       atom               x         y         z"))
       {
         printf("$coord 1.0\n");
         numat=0;
@@ -179,6 +188,34 @@ int main(int argc, char **argv)
           fgets(line, MAXLENLINE, file);
         }
       }
+      else if (strstr(line, "no. atom      x        y        z      no. atom      x        y        z") && numat == 0)
+      {
+	isVamp=TRUE;
+        printf("$coord 1.0\n");
+        numat=0;
+        fgets(line, MAXLENLINE, file);
+        fgets(line, MAXLENLINE, file);
+        while (line[0] != '\n')
+        {
+          (void)strtok(line, " \t");
+          j=atoi(strtok(NULL, " \t"))-1;
+          x=atof(strtok(NULL, " \t"));
+          y=atof(strtok(NULL, " \t"));
+          z=atof(strtok(NULL, " \t"));
+          printf("%22.14f%22.14f%22.14f  %s\n", x, y, z, pse[j]);
+          numat++;
+          if (strtok(NULL, " \t") != NULL)
+	  {
+            j=atoi(strtok(NULL, " \t"))-1;
+            x=atof(strtok(NULL, " \t"));
+            y=atof(strtok(NULL, " \t"));
+            z=atof(strtok(NULL, " \t"));
+            printf("%22.14f%22.14f%22.14f  %s\n", x, y, z, pse[j]);
+            numat++;
+            fgets(line, MAXLENLINE, file);
+	  }
+        }
+      }
     }
 /*  if (strstr(line, "NO. OF DOUBLY OCCUPIED LEVELS") && norbs == 0)
     {
@@ -198,12 +235,36 @@ int main(int argc, char **argv)
         printf("$title\n%s", line);
       }
     }
-    else if (strstr(line, "VIBRATIONS ARE THE TRANSLATION"))
+    else if (strstr(line, "vibrations are the translation"))
     {
       line[14]='\0';
       dof=3*numat-atoi(&line[13]);
     }
-    else if (strstr(line, "NORMAL COORDINATE ANALYSIS"))
+    else if (strstr(line, "translations and rotations (cm-1)"))
+    {
+      isVamp=TRUE;
+      fgets(line, MAXLENLINE, file);
+      while (!strstr(line, "Vibration        Frequency       Reduced        I.R.       Raman"))
+        fgets(line, MAXLENLINE, file);
+      fgets(line, MAXLENLINE, file);
+      fgets(line, MAXLENLINE, file);
+      fgets(line, MAXLENLINE, file);
+      fgets(line, MAXLENLINE, file);
+      printf("$vibrational spectrum\n");
+      dof=0;
+      while (line[0] != '\n')
+      {
+	dof++;
+	(void)strtok(line, " \t");
+	printf("%s ", strtok(NULL, " \t\n"));
+	printf("%s ", strtok(NULL, " \t\n"));
+	(void)strtok(NULL, " \t\n");
+	printf("%s ", strtok(NULL, " \t\n"));
+	printf("%s\n", strtok(NULL, " \t\n"));
+        fgets(line, MAXLENLINE, file);
+      }
+    }
+    else if (strstr(line, "normal coordinate analysis"))
     {
       wn=(double *)getmem((size_t)dof, sizeof(double));
       sym=(char *)getmem((size_t)dof, 8*sizeof(char));
@@ -217,7 +278,8 @@ int main(int argc, char **argv)
           if (line[0] == '1') fgets(line, MAXLENLINE, file);
         }
         fgets(line, MAXLENLINE, file);
-        if (strstr(line, "ROOT NO.")) hasSymLabels=FALSE;
+	makeLower(line);
+        if (strstr(line, "root no.")) hasSymLabels=FALSE;
         else                          hasSymLabels=TRUE;
         if (hasSymLabels)
         {
@@ -250,12 +312,17 @@ int main(int argc, char **argv)
         for (i=0; i<3*numat; i++)
         {
           fgets(line, MAXLENLINE, file);
-          if (line[0] == '1') fgets(line, MAXLENLINE, file);
-          (void)strtok(line, " \t");
+          if (line[0] == '1' || line[0] == '\n') fgets(line, MAXLENLINE, file);
+          word=strtok(line, " \t");
+	  if (!isdigit(word[0]))
+	  {
+            (void)strtok(NULL, " \t");
+            (void)strtok(NULL, " \t");
+	  }
           for (j=0; j<last; j++)
             cnm[dof*i+k-last+j]=atof(strtok(NULL, " \t"));
         }
-      }
+      } /* end of "while (k < dof)" */
       printf("$vibrational normal modes\n");
       for (i=1; i<=3*numat; i++)
       {
@@ -267,17 +334,20 @@ int main(int argc, char **argv)
         }
         printf("\n");
       }
-      printf("$vibrational spectrum\n");
-      i=0;
+      if (!isVamp)
+      {
+        printf("$vibrational spectrum\n");
+        i=0;
+      }
     }
-    else if (strstr(line, "T-DIPOLE") && i < dof)
+    else if (strstr(line, "t-dipole") && i < dof)
     {
       (void)strtok(line, " \t");
       word=strtok(NULL, " \t");
       printf("%s %f %s 1.0\n", &sym[8*i], wn[i], word);
       i++;
     }
-    else if (strstr(line, "EIGENVALUES"))
+    else if (strstr(line, "eigenvalues") && !strstr(line, "<>"))
     {
       if (norbs == 0) norbs=50;
       e=(double *)getmem((size_t)norbs, sizeof(double));
@@ -301,17 +371,18 @@ int main(int argc, char **argv)
       }
       norbs=i;
     }
-    else if (strstr(line, "  EIGENVECTORS"))
+    else if (strstr(line, "  eigenvectors"))
     {
       i=0;
       if (norbs == 0) norbs=50;
       e=(double *)getmem((size_t)norbs, sizeof(double));
       fgets(line, MAXLENLINE, file);
+      makeLower(line);
       buffer=NULL;
       while (!buffer)
       {
-        while (strstr(line, "ROOT NO.") == NULL && (buffer=strstr(line,
-               "NET ATOMIC CHARGES")) == NULL) fgets(line, MAXLENLINE, file);
+        while (strstr(line, "root no.") == NULL && (buffer=strstr(line,
+               "net atomic charges")) == NULL) fgets(line, MAXLENLINE, file);
         if (!buffer)
           {
           fgets(line, MAXLENLINE, file);
@@ -427,3 +498,14 @@ double passDouble(double *dp)
 {
   return(*dp);
 }
+
+void makeLower(char *line)
+{
+  char *p=line;
+
+  while (*p)
+  {
+    *p=tolower(*p);
+    p++;
+  }
+}
