@@ -4,12 +4,15 @@
 *                                                                              *
 *                                 S A V E . C                                  *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: save.c,v 1.5 2000/12/10 15:16:29 jrh Exp $
+* $Id: save.c,v 1.6 2003/11/07 11:15:35 jrh Exp $
 * $Log: save.c,v $
+* Revision 1.6  2003/11/07 11:15:35  jrh
+* Release 2.4
+*
 * Revision 1.5  2000/12/10 15:16:29  jrh
 * Release 2.3
 *
@@ -26,6 +29,7 @@
 * Initial revision
 *
 */
+#include<locale.h>
 #include<math.h>
 #include<stdio.h>
 #include<stdlib.h>
@@ -44,8 +48,8 @@ extern int  getIntResource(Widget, char *);
 extern void getRGBColor(Widget, Pixel, float *, float *, float *);
 extern int  messgb(Widget, int, char *, struct PushButtonRow *, int);
 extern int checkFile(char **);
-extern double bondLength(struct MOLECULE *, int, int);
-extern double bondAngle(struct MOLECULE *, int, int, int);
+extern double bondLength(struct ATOM *, int, int);
+extern double bondAngle(struct ATOM *, int, int, int);
 extern double dist(double, double, double, double, double, double);
 extern double angle(double, double, double, double, double, double, double,
                     double, double);   
@@ -67,7 +71,7 @@ extern double sphereres, lineWidth, level, denres, hbondThreshold;
 extern int outputType, saveLanguage, automaticRecalculate, saveAll;
 extern int primitive, bondType, interp, simplify, nmolecule, thermoUnits;
 extern Widget topShell;
-extern char language[], webbrowser[], moloch[], rayshade[], displayRLE[];
+extern char language[], webbrowser[], moloch[], raytracer[], displayImage[];
 
 void saveMolecule(char *name)
 {
@@ -80,8 +84,9 @@ void saveMolecule(char *name)
   double a2bohr=1.0/0.52917706;
   double a, b, c, alpha, beta, gamma;
   char *word, line[MAXLENLINE], command[MAXLENLINE];
+  const char *locale;
   int cell;
-  register int i, j, k, n;
+  register int i, j, k;
 
   if (name == NULL)
     filename=selectFile("*", filename, TRUE);
@@ -115,54 +120,62 @@ void saveMolecule(char *name)
       return;
     }
 
+    locale=setlocale(LC_ALL, "C");
     if (windows[VIEWER].set >= 0)
     {
       mol=&molecules[windows[VIEWER].set];
-      n=mol->na;
-      if (mol->existsUnitCell)
+      if (mol->unitcell)
       {
-        n-=8;
-        a=bondLength(mol, n, n+1);
-        b=bondLength(mol, n, n+2);
-        c=bondLength(mol, n, n+3);
-        alpha=bondAngle(mol, n+2, n, n+3);
-        beta=bondAngle(mol, n+1, n, n+3);
-        gamma=bondAngle(mol, n+1, n, n+2);
+        a=bondLength(mol->unitcell->corners, 0, 1);
+        b=bondLength(mol->unitcell->corners, 0, 2);
+        c=bondLength(mol->unitcell->corners, 0, 3);
+        alpha=bondAngle(mol->unitcell->corners, 2, 0, 3);
+        beta=bondAngle(mol->unitcell->corners, 1, 0, 3);
+        gamma=bondAngle(mol->unitcell->corners, 1, 0, 2);
         fprintf(file, "$unitcell %10.6f %10.6f %10.6f %10.3f %10.3f %10.3f\n",
                 a*a2bohr, b*a2bohr, c*a2bohr, alpha, beta, gamma);
       }
       fprintf(file, "$coord\n");
-      for (i=0; i<n; i++)
+      for (i=0; i<mol->na; i++)
       {
-	  if (saveAll || (mol->atoms[i].flags & SELECTED))
-	  {
-          fprintf(file, "%22.14f%22.14f%22.14f  %s\n",
-                  (mol->atoms[i].x-mol->transx)*a2bohr,
-                  (mol->atoms[i].y-mol->transy)*a2bohr,
-                  (mol->atoms[i].z-mol->transz)*a2bohr,
-                   mol->atoms[i].name);
-	  }
+	if (!(mol->atoms[i].flags & DISPLAY_ONLY))
+	{
+          if (saveAll || (mol->atoms[i].flags & SELECTED))
+          {
+            fprintf(file, "%22.14f%22.14f%22.14f  %s\n",
+                    (mol->atoms[i].x-mol->transx)*a2bohr,
+                    (mol->atoms[i].y-mol->transy)*a2bohr,
+                    (mol->atoms[i].z-mol->transz)*a2bohr,
+                     mol->atoms[i].name);
+          }
+        }
       }
       fprintf(file, "$bonds\n");
       for (i=0; i<mol->nb; i++)
-        fprintf(file, "%d %d %d\n", mol->bonds[i].first+1,
-                mol->bonds[i].second+1, mol->bonds[i].order);
-	if (mol->nhist > 0)
-	{
-	  fprintf(file, "$grad          cartesian gradients\n");
-	  for (i=0; i<mol->nhist; i++)
-	  {
-	    fprintf(file, "  cycle =  %d    SCF energy = %17.10f   |dE/dxyz| =   %9.6f\n",
-			i+1, mol->optimization[i].energy, mol->optimization[i].gnorm);
-	    j=mol->optimization[i].coords;
-	    if (mol->existsUnitCell)
-	    {
-            a=dist(mol->history[j+n].x, mol->history[j+n].y, mol->history[j+n].z,
-			 mol->history[j+n+1].x, mol->history[j+n+1].y, mol->history[j+n+1].z);
+      {
+        if (!(mol->atoms[mol->bonds[i].first].flags & DISPLAY_ONLY) &&
+            !(mol->atoms[mol->bonds[i].second].flags & DISPLAY_ONLY))
+        {
+          fprintf(file, "%d %d %d\n", mol->bonds[i].first+1,
+                  mol->bonds[i].second+1, mol->bonds[i].order);
+        }
+      }
+      if (mol->nhist > 0)
+      {
+        fprintf(file, "$grad          cartesian gradients\n");
+        for (i=0; i<mol->nhist; i++)
+        {
+          fprintf(file, "  cycle =  %d    SCF energy = %17.10f   |dE/dxyz| =   %9.6f\n",
+                  i+1, mol->optimization[i].energy, mol->optimization[i].gnorm);
+          j=mol->optimization[i].coords;
+          if (mol->unitcell)
+          {
+/*          a=dist(mol->history[j+n].x, mol->history[j+n].y, mol->history[j+n].z,
+                   mol->history[j+n+1].x, mol->history[j+n+1].y, mol->history[j+n+1].z);
             b=dist(mol->history[j+n].x, mol->history[j+n].y, mol->history[j+n].z,
-			 mol->history[j+n+2].x, mol->history[j+n+2].y, mol->history[j+n+2].z);
+                   mol->history[j+n+2].x, mol->history[j+n+2].y, mol->history[j+n+2].z);
             c=dist(mol->history[j+n].x, mol->history[j+n].y, mol->history[j+n].z,
-			 mol->history[j+n+3].x, mol->history[j+n+3].y, mol->history[j+n+3].z);
+                   mol->history[j+n+3].x, mol->history[j+n+3].y, mol->history[j+n+3].z);
             alpha=angle(mol->history[j+n+2].x, mol->history[j+n+2].y, mol->history[j+n+2].z,
                         mol->history[j+n].x, mol->history[j+n].y, mol->history[j+n].z,
                         mol->history[j+n+3].x, mol->history[j+n+3].y, mol->history[j+n+3].z);
@@ -171,30 +184,38 @@ void saveMolecule(char *name)
                        mol->history[j+n+3].x, mol->history[j+n+3].y, mol->history[j+n+3].z);
             gamma=angle(mol->history[j+n+1].x, mol->history[j+n+1].y, mol->history[j+n+1].z,
                         mol->history[j+n].x, mol->history[j+n].y, mol->history[j+n].z,
-                        mol->history[j+n+2].x, mol->history[j+n+2].y, mol->history[j+n+2].z);
+                        mol->history[j+n+2].x, mol->history[j+n+2].y, mol->history[j+n+2].z); */
             fprintf(file, "  unitcell %10.6f %10.6f %10.6f %10.3f %10.3f %10.3f\n",
-                    a*a2bohr, b*a2bohr, c*a2bohr, alpha, beta, gamma);
-	    }
-	    for (k=j; k<j+n; k++)
+                    mol->unitcell[i+1].a*a2bohr, mol->unitcell[i+1].b*a2bohr,
+                    mol->unitcell[i+1].c*a2bohr, mol->unitcell[i+1].alpha,
+                    mol->unitcell[i+1].beta, mol->unitcell[i+1].gamma);
+          }
+          for (k=j; k<j+mol->na; k++)
+          {
+	    if (!(mol->atoms[k-j].flags & DISPLAY_ONLY))
 	    {
-		if (saveAll || (mol->atoms[k-j].flags & SELECTED))
-		{
-	 	  fprintf(file, "%22.14f%22.14f%22.14f  %s\n",
-		  	    mol->history[k].x*a2bohr, mol->history[k].y*a2bohr,
-			    mol->history[k].z*a2bohr, mol->atoms[k-j].name);
-		}
+              if (saveAll || (mol->atoms[k-j].flags & SELECTED))
+              {
+                 fprintf(file, "%22.14f%22.14f%22.14f  %s\n",
+                         mol->history[k].x*a2bohr, mol->history[k].y*a2bohr,
+                         mol->history[k].z*a2bohr, mol->atoms[k-j].name);
+              }
 	    }
-	    for (k=j; k<j+n; k++)
+          }
+          for (k=j; k<j+mol->na; k++)
+          {
+	    if (!(mol->atoms[k-j].flags & DISPLAY_ONLY))
 	    {
-		if (saveAll || (mol->atoms[k-j].flags & SELECTED))
-		{
-	  	  fprintf(file, "%22.14e%22.14e%22.14e\n",
-			    mol->history[k].gx/a2bohr, mol->history[k].gy/a2bohr,
-			    mol->history[k].gz/a2bohr);
-		}
+              if (saveAll || (mol->atoms[k-j].flags & SELECTED))
+              {
+                  fprintf(file, "%22.14f%22.14f%22.14f\n",
+                          mol->history[k].gx/a2bohr, mol->history[k].gy/a2bohr,
+                          mol->history[k].gz/a2bohr);
+              }
 	    }
-	  }
-	}
+          }
+        }
+      }
     }
     else
     {
@@ -202,22 +223,22 @@ void saveMolecule(char *name)
       for (i=0; i<nmolecule; i++)
       {
         mol=&molecules[i];
-        n=mol->na;
-        if (mol->existsUnitCell && !cell)
+        if (mol->unitcell && !cell)
         {
-          n-=8;
-          a=bondLength(mol, n, n+1);
-          b=bondLength(mol, n, n+2);
-          c=bondLength(mol, n, n+3);
-          alpha=bondAngle(mol, n+2, n, n+3);
-          beta=bondAngle(mol, n+1, n, n+3);
-          gamma=bondAngle(mol, n+1, n, n+2);
+/*        a=bondLength(mol->unitcell->corners, 0, 1);
+          b=bondLength(mol->unitcell->corners, 0, 2);
+          c=bondLength(mol->unitcell->corners, 0, 3);
+          alpha=bondAngle(mol->unitcell->corners, 2, 0, 3);
+          beta=bondAngle(mol->unitcell->corners, 1, 0, 3);
+          gamma=bondAngle(mol->unitcell->corners, 1, 0, 2); */
           fprintf(file, "$unitcell %10.6f %10.6f %10.6f %10.3f %10.3f %10.3f\n",
-                  a*a2bohr, b*a2bohr, c*a2bohr, alpha, beta, gamma);
+                  mol->unitcell->a*a2bohr, mol->unitcell->b*a2bohr,
+                  mol->unitcell->c*a2bohr, mol->unitcell->alpha,
+                  mol->unitcell->beta, mol->unitcell->gamma);
           cell=TRUE;
         }
         if (i == 0) fprintf(file, "$coord\n");
-        for (j=0; j<n; j++)
+        for (j=0; j<mol->na; j++)
           fprintf(file, "%22.14f%22.14f%22.14f  %s\n",
                   (mol->atoms[j].x-mol->transx)*a2bohr,
                   (mol->atoms[j].y-mol->transy)*a2bohr,
@@ -235,6 +256,7 @@ void saveMolecule(char *name)
     }
     fprintf(file, "$end\n");
     pclose(file);
+    (void)setlocale(LC_ALL, locale);
 
     if (name == NULL)
     {
@@ -256,6 +278,7 @@ void saveConfiguration(void)
   const char *interpolation[]={"none", "linear", "logarithmic"};
   const char *recalculate[]={"False", "True"};
   const char *units[]={"joules", "calories", "thermochemical calories"};
+  const char *locale;
   char *paper[]={"A5", "A4", "A3", "Letter", "Legal", "100.0x100.0"};
   int nconfig=0, paperSize;
   char *word, *config=NULL, *p;
@@ -301,10 +324,10 @@ void saveConfiguration(void)
   checkStringResource("webBrowser", (const char **)str, 1, 1, &config, &nconfig);
   *str=(char *)&moloch;
   checkStringResource("Moloch", (const char **)str, 1, 1, &config, &nconfig);
-  *str=(char *)&rayshade;
-  checkStringResource("Rayshade", (const char **)str, 1, 1, &config, &nconfig);
-  *str=(char *)&displayRLE;
-  checkStringResource("DisplayRLE", (const char **)str, 1, 1, &config, &nconfig);
+  *str=(char *)&raytracer;
+  checkStringResource("Raytracer", (const char **)str, 1, 1, &config, &nconfig);
+  *str=(char *)&displayImage;
+  checkStringResource("DisplayImage", (const char **)str, 1, 1, &config, &nconfig);
   checkIntResource("sphereResolution", (int)sphereres, &config, &nconfig);
   checkIntResource("lineWidth", (int)lineWidth, &config, &nconfig);
   checkDoubleResource("isosurface", level, &config, &nconfig);
@@ -317,6 +340,7 @@ void saveConfiguration(void)
   checkWindowResource(&windows[MO], "MODiagram", &config, &nconfig);
   if (saveLanguage) copyLanguageResources(&config, &nconfig);
 
+  locale=setlocale(LC_ALL, "C");
   if ((home=getenv("HOME")) != NULL)
   {
     strcpy(f, home);
@@ -381,6 +405,7 @@ void saveConfiguration(void)
     word=getStringResource(topShell, "ConfigurationSaved");
     messgb(topShell, 0, word, buttons, 1);
   }
+  (void)setlocale(LC_ALL, locale);
   if (config)
     fremem((void *)&config);
 }
@@ -581,8 +606,9 @@ void copyLanguageResources(char **config, int *nconfig)
   char filename[FILENAME_MAX], line[MAXLENLINE], *p;
 
   strcpy(filename, getenv("VIEWMOLPATH"));
-  strcat(filename, "/Xdefaults.");
+  strcat(filename, "/locale/");
   strcat(filename, language);
+  strcat(filename, "/Viewmol");
   if ((file=fopen(filename, "r")) != NULL)
   {
     mc=*nconfig;
@@ -601,7 +627,7 @@ void copyLanguageResources(char **config, int *nconfig)
     i=*nconfig;
     while (fgets(line, MAXLENLINE, file) != NULL)
     {
-      if (!strncmp(line, "Viewmol.title", 13)) copy=TRUE;
+      if (!strncmp(line, "Viewmol.language", 16)) copy=TRUE;
       if (copy)
       {
         strncpy(p, line, MAXLENLINE);
