@@ -4,12 +4,15 @@
 *                                                                              *
 *                             S P E C F O R M . C                              *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: specform.c,v 1.5 2000/12/10 15:16:52 jrh Exp $
+* $Id: specform.c,v 1.6 2003/11/07 11:16:18 jrh Exp $
 * $Log: specform.c,v $
+* Revision 1.6  2003/11/07 11:16:18  jrh
+* Release 2.4
+*
 * Revision 1.5  2000/12/10 15:16:52  jrh
 * Release 2.3
 *
@@ -55,6 +58,8 @@ void spectrumDialogExit(Widget, caddr_t, XmPushButtonCallbackStruct *);
 void GetIns(Widget, caddr_t, XmToggleButtonCallbackStruct *);
 void GetInsWeight(Widget, caddr_t, XmToggleButtonCallbackStruct *);
 void GetDouble(Widget, caddr_t, XmToggleButtonCallbackStruct *);
+void GetOption(Widget, caddr_t, XmToggleButtonCallbackStruct *);
+void GetLineWidth(Widget, caddr_t, XmToggleButtonCallbackStruct *);
 
 extern void MapBox(Widget, caddr_t, XmAnyCallbackStruct *);
 extern Widget CreateToggleBox(Widget, struct PushButtonRow *, int, int,
@@ -75,22 +80,23 @@ extern Widget initShell(Widget, char *, Widget *, Widget *);
 
 extern struct WINDOW windows[];
 extern struct MOLECULE *molecules;
-extern int animate, lines, setins;
+extern int animate, lines, setins, xIsTop, showGrid;
 extern int setinsAnnotation;
-extern double weight, temp, amplitude, wnScale;
+extern double weight, temp, amplitude, wnScale, spectrumLineWidth;
 extern Widget topShell;
 extern Pixel stdcol[9];
 
 static Widget dialog, insweight;
-static int mode_save, animate_save, lines_save, setins_save;
-static double weight_save, temp_save, amplitude_save, wnScale_save;
+static int mode_save, animate_save, lines_save, setins_save, xIsTop_save, showGrid_save;
+static double weight_save, temp_save, amplitude_save, wnScale_save, lineWidth_save;
 
 void spectrumDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
 {
-  Widget board, form, form1, form2, form3, form4;
+  Widget board, form, form1, form2, form3, form4, form5;
   Widget radiobox1, radiobox2, radiobox3;
   Widget ins, slider1, slider2, slider3, temperature, ampl, scale;
-  Widget sep1, sep2, sep3, sep4, sep5;
+  Widget axisTop, lineWidthLabel, lineWidthWidget, showGridWidget;
+  Widget sep1, sep2, sep3, sep4, sep5, sep6;
   static struct SLIDER tempSlider, amplitudeSlider, scaleSlider;
   short decimals;
   char str[20];
@@ -126,6 +132,9 @@ void spectrumDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
   temp_save=temp;
   amplitude_save=amplitude;
   wnScale_save=wnScale;
+  xIsTop_save=xIsTop;
+  showGrid_save=showGrid;
+  lineWidth_save=spectrumLineWidth;
 
   dialog=initShell(windows[SPECTRUM].widget, "spectrumForm", &board,
 			 &form);
@@ -300,10 +309,51 @@ void spectrumDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
                                XmNrightAttachment, XmATTACH_FORM,
                                NULL);
 
+  form5=XtVaCreateWidget("controlarea5", xmFormWidgetClass, form, NULL);
+  axisTop=XtVaCreateManagedWidget("axisTop", xmToggleButtonWidgetClass, form5,
+                                  XmNleftAttachment, XmATTACH_FORM,
+                                  XmNtopAttachment, XmATTACH_FORM,
+                                  XmNbottomAttachment, XmATTACH_FORM,
+                                  NULL);
+  if (xIsTop) XtVaSetValues(axisTop, XmNset, True, NULL);
+  XtAddCallback(axisTop, XmNvalueChangedCallback, (XtCallbackProc)GetOption, &xIsTop);
+  showGridWidget=XtVaCreateManagedWidget("showGrid", xmToggleButtonWidgetClass, form5,
+                                         XmNleftAttachment, XmATTACH_WIDGET,
+                                         XmNleftWidget, axisTop,
+                                         XmNtopAttachment, XmATTACH_FORM,
+                                         XmNbottomAttachment, XmATTACH_FORM,
+                                         NULL);
+  if (showGrid) XtVaSetValues(showGridWidget, XmNset, True, NULL);
+  XtAddCallback(showGridWidget, XmNvalueChangedCallback, (XtCallbackProc)GetOption, &showGrid);
+  sprintf(str, "%f", spectrumLineWidth);
+  lineWidthWidget=XtVaCreateManagedWidget("lineWidth", xmTextWidgetClass, form5,
+                                          XmNvalue, str,
+                                          XmNcolumns, 4,
+                                          XmNtopAttachment, XmATTACH_FORM,
+                                          XmNrightAttachment, XmATTACH_FORM,
+                                          XmNbottomAttachment, XmATTACH_FORM,
+                                          NULL);
+  XtAddCallback(lineWidthWidget, XmNvalueChangedCallback, (XtCallbackProc)GetLineWidth,
+                NULL);
+  lineWidthLabel=XtVaCreateManagedWidget("lineWidthLabel", xmLabelWidgetClass, form5,
+                                         XmNrightAttachment, XmATTACH_WIDGET,
+			                       XmNrightWidget, lineWidthWidget,
+                                         XmNtopAttachment, XmATTACH_FORM,
+                                         XmNbottomAttachment, XmATTACH_FORM,
+                                         NULL);
+
+  sep6=XtVaCreateManagedWidget("sep6", xmSeparatorWidgetClass, form,
+                               XmNtraversalOn, False,
+                               XmNleftAttachment, XmATTACH_FORM,
+                               XmNtopAttachment, XmATTACH_WIDGET,
+                               XmNtopWidget, axisTop,
+                               XmNrightAttachment, XmATTACH_FORM,
+                               NULL);
   XtManageChild(form1);
   XtManageChild(form2);
   XtManageChild(form3);
   XtManageChild(form4);
+  XtManageChild(form5);
 
   CreatePushButtonRow(form, buttons, 2);
   XtAddCallback(dialog, XmNpopupCallback, (XtCallbackProc)MapBox, (XmAnyCallbackStruct *)NULL);
@@ -424,6 +474,21 @@ void GetInsWeight(Widget button, caddr_t dummy, XmToggleButtonCallbackStruct *da
   redraw(VIEWER);
 }
 
+void GetOption(Widget button, caddr_t dest, XmToggleButtonCallbackStruct *data)
+{
+  if (data->set)
+    *(int *)dest=TRUE;
+  else
+    *(int *)dest=FALSE;
+  redraw(SPECTRUM);
+}
+
+void GetLineWidth(Widget field, caddr_t dummy, XmToggleButtonCallbackStruct *data)
+{
+  GetDouble(field, (caddr_t)&spectrumLineWidth, data);
+  redraw(SPECTRUM);
+}
+
 void GetDouble(Widget button, caddr_t dest, XmToggleButtonCallbackStruct *data)
 {
   char *str;
@@ -446,6 +511,9 @@ void spectrumDialogExit(Widget button, caddr_t which, XmPushButtonCallbackStruct
     temp=temp_save;
     amplitude=amplitude_save;
     wnScale=wnScale_save;
+    xIsTop=xIsTop_save;
+    showGrid=showGrid_save;
+    spectrumLineWidth=lineWidth_save;
     deleteAnnotation(&setinsAnnotation);
     restoreGeometry(molecules[windows[SPECTRUM].set].coord, windows[SPECTRUM].set);
     sprintf(t, "title%.1d", windows[SPECTRUM].mode);
