@@ -4,12 +4,15 @@
 *                                                                              *
 *                           T H E R M O F O R M . C                            *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: thermoform.c,v 1.1 2000/12/10 15:17:42 jrh Exp $
+* $Id: thermoform.c,v 1.2 2003/11/07 11:16:54 jrh Exp $
 * $Log: thermoform.c,v $
+* Revision 1.2  2003/11/07 11:16:54  jrh
+* Release 2.4
+*
 * Revision 1.1  2000/12/10 15:17:42  jrh
 * Initial revision
 *
@@ -61,7 +64,7 @@ extern Widget makeMenu(Widget, int, char *, struct MenuItem *);
 extern char *getStringResource(Widget, char *);
 extern double getMass(struct MOLECULE *);
 extern double getDensity(struct MOLECULE *);
-extern void getSumFormula(struct MOLECULE *, char *);
+extern void getSumFormula(struct MOLECULE *, char *, int);
 extern void selectMolecule(Widget, caddr_t, XmToggleButtonCallbackStruct *);
 extern Widget CreateToggleBox(Widget, struct PushButtonRow *, int, int, int, int, int);
 extern int reaction(int, int *);
@@ -167,7 +170,7 @@ void thermoDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
   for (i=0; i<nmolecule; i++)
   {
     mol=&molecules[i];
-    getSumFormula(mol, formula);
+    getSumFormula(mol, formula, TRUE);
     str=makeIndexedString(formula);
     (void)XtVaCreateManagedWidget(formula, xmPushButtonWidgetClass, tabs,
                                   XmNlabelString, str,
@@ -227,7 +230,7 @@ void thermoDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
 
     XmStringFree(str);
 
-    if (mol->existsUnitCell)
+    if (mol->unitcell)
     {
       format=getStringResource(board, "solidDensity");
       sprintf(line, format, getDensity(mol));
@@ -599,7 +602,7 @@ void makeReaction(char *eq, double *reactionData)
   {
     if (molecules[i].stoichioNumber < 0)
     {
-      getSumFormula(&molecules[i], formula);
+      getSumFormula(&molecules[i], formula, TRUE);
       if (*leftSide) strcat(leftSide, " + ");
       if (molecules[i].stoichioNumber == (-1))
         strcat(leftSide, formula);
@@ -624,7 +627,7 @@ void makeReaction(char *eq, double *reactionData)
     }
     else if (molecules[i].stoichioNumber > 0)
     {
-      getSumFormula(&molecules[i], formula);
+      getSumFormula(&molecules[i], formula, TRUE);
       if (*rightSide) strcat(rightSide, " + ");
       if (molecules[i].stoichioNumber == 1)
         strcat(rightSide, formula);
