@@ -8,8 +8,11 @@
 *                                                                              *
 ********************************************************************************
 *
-* $Id: tm.c,v 1.6 2003/11/07 11:17:02 jrh Exp $
+* $Id: tm.c,v 1.7 2004/08/29 15:02:04 jrh Exp $
 * $Log: tm.c,v $
+* Revision 1.7  2004/08/29 15:02:04  jrh
+* Release 2.4.1
+*
 * Revision 1.6  2003/11/07 11:17:02  jrh
 * Release 2.4
 *
@@ -149,23 +152,31 @@ int main(int argc, char **argv)
           {
              if (line[0] != '#')
             {
-              column[0]=strtok(line, " \t");
-              column[1]=strtok(NULL, " \t");
-              column[2]=strtok(NULL, " \t");
-              column[3]=strtok(NULL, " \t");
-              column[4]=strtok(NULL, " \t");
-              column[5]=strtok(NULL, " \t");
-              if (*column[4] != '-')
-              {
+              column[0]=strtok(line, " \t\n");
+              column[1]=strtok(NULL, " \t\n");
+              column[2]=strtok(NULL, " \t\n");
+              column[3]=strtok(NULL, " \t\n");
+	      if (column[3] == NULL)
+	      {
                 column[1][0]=(char)toupper(column[1][0]);
-                printf("%s %s %s ", column[1], column[2], column[3]);
-                if (strstr(column[5], "NO"))
-                  printf("0.0000000\n");
-                else
-                  printf("1.0000000\n");
-              }
+                printf("%s %s 1.0000000 1.0000000\n", column[1], column[2]);
+	      }
+	      else
+	      {
+                column[4]=strtok(NULL, " \t\n");
+                column[5]=strtok(NULL, " \t\n");
+                if (*column[4] != '-')
+                {
+                  column[1][0]=(char)toupper(column[1][0]);
+                  printf("%s %s %s ", column[1], column[2], column[3]);
+                  if (strstr(column[5], "NO"))
+                    printf("0.0000000\n");
+                  else
+                    printf("1.0000000\n");
+                }
                 else
                   printf("- %s %s 0.0000000\n", column[1], column[2]);
+	      }
             }
             if (fgets(line, MAXLENLINE, file) == NULL) break;
           }
@@ -355,7 +366,8 @@ int main(int argc, char **argv)
               if (strstr(line, "$origin") || strstr(line, "$vector") || 
                   strstr(line, "$grid") || strstr(line, "$title") ||
                   strstr(line, "$plotdata")) line[0]=' ';
-              printf("%s", line);
+              changeDs(line);
+              printf("%s\n", line);
             }
             fclose(file);
           }
