@@ -4,12 +4,15 @@
 *                                                                              *
 *                        V I E W M O L M O D U L E . C                         *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: viewmolmodule.c,v 1.1 2000/12/10 15:18:35 jrh Exp $
+* $Id: viewmolmodule.c,v 1.2 2003/11/07 11:17:17 jrh Exp $
 * $Log: viewmolmodule.c,v $
+* Revision 1.2  2003/11/07 11:17:17  jrh
+* Release 2.4
+*
 * Revision 1.1  2000/12/10 15:18:35  jrh
 * Initial revision
 *
@@ -41,6 +44,9 @@ static PyObject *viewmol_showThermodynamics(PyObject *, PyObject *);
 static PyObject *viewmol_redraw(PyObject *, PyObject *);
 static PyObject *viewmol_getFramesPerSecond(PyObject *, PyObject *);
 static PyObject *viewmol_write(PyObject *, PyObject *);
+static PyObject *viewmol_registerMenuItem(PyObject *, PyObject *);
+static PyObject *viewmol_showWarnings(PyObject *, PyObject *);
+static PyObject *viewmol_getWindowSize(PyObject *, PyObject *);
 static PyObject *viewmol_quit(PyObject *, PyObject *);
 int checkInterrupt(void);
 
@@ -53,6 +59,7 @@ extern void setDrawingMode(Widget, caddr_t, XmToggleButtonCallbackStruct *);
 extern void setProjection(Widget, caddr_t, XmToggleButtonCallbackStruct *);
 extern void switchLight(Widget, caddr_t, XmToggleButtonCallbackStruct *);
 extern void thermoDialog(Widget, caddr_t, XmAnyCallbackStruct *);
+extern void annotateWavefunction(void);
 extern void redraw(int);
 extern void ende(Widget, caddr_t, XmAnyCallbackStruct *);
 extern void saveDrawing(int, int, char *);
@@ -61,6 +68,7 @@ extern Boolean normalMode(XtPointer);
 extern int findMolecule(PyMoleculeSpecObject *);
 extern void deleteMolecule(Widget, caddr_t, XmAnyCallbackStruct *);
 extern void infoSetText(char *);
+extern void setShape(int, Dimension, Dimension);
 extern PyLightSpecObject *light_new(void);
 
 extern struct WINDOW windows[];
@@ -70,6 +78,8 @@ extern struct ANNOTATION *annotation;
 extern double lineWidth, sphereres, level, drawingSpeed;
 extern int primitive, projectionMode, nAnnotations;
 extern int nmolecule, imol, label, outputType, noutput, animate, pythonInterrupt;
+extern int showWarning;
+extern char *moduleName;
 
 static PyMethodDef viewmol_methods[] = {
   {"load",                viewmol_load, 1},
@@ -92,6 +102,9 @@ static PyMethodDef viewmol_methods[] = {
   {"redraw",              viewmol_redraw, 1},
   {"getFramesPerSecond",  viewmol_getFramesPerSecond, 1},
   {"write",               viewmol_write, 1},
+  {"registerMenuItem",    viewmol_registerMenuItem, 1},
+  {"showWarnings",        viewmol_showWarnings, 1},
+  {"getWindowSize",       viewmol_getWindowSize, 1},
   {"quit",                viewmol_quit, 1},
   {NULL,                  NULL}
 };
@@ -329,7 +342,7 @@ static PyObject *viewmol_groundColor(PyObject *self, PyObject *args)
       PyTuple_SetItem(tuple, 0, PyFloat_FromDouble((double)windows[VIEWER].foreground_rgb[0]));
       PyTuple_SetItem(tuple, 1, PyFloat_FromDouble((double)windows[VIEWER].foreground_rgb[1]));
       PyTuple_SetItem(tuple, 2, PyFloat_FromDouble((double)windows[VIEWER].foreground_rgb[2]));
-	return(tuple);
+      return(tuple);
     }
   }
   else                                     /* set */
@@ -414,8 +427,8 @@ static PyObject *viewmol_saveDrawing(PyObject *self, PyObject *args)
     PyErr_SetString(PyExc_IOError, "File already exists.");
     return(NULL);
   }
-  if (format != TIFFFILE && format != HPGL &&
-	format != POSTSCRIPT && format != RAYTRACER)
+  if (format != TIFFFILE && format != PNGFILE && format != HPGL &&
+      format != POSTSCRIPT && format != RAYTRACER)
   {
     PyErr_SetString(PyExc_ValueError, "Format not recognised.");
     return(NULL);
@@ -436,6 +449,7 @@ static PyObject *viewmol_isosurface(PyObject *self, PyObject *args)
   else
   {
     level=l;
+    annotateWavefunction();
     Py_INCREF(Py_None);
     return(Py_None);
   }
@@ -488,6 +502,49 @@ static PyObject *viewmol_write(PyObject *self, PyObject *args)
   return(Py_None);
 }
 
+static PyObject *viewmol_registerMenuItem(PyObject *self, PyObject *args)
+{
+  if (checkInterrupt()) return(NULL);
+  if (!PyArg_ParseTuple(args, "s", &moduleName)) return(NULL);
+
+  Py_INCREF(Py_None);
+  return(Py_None);
+}
+
+static PyObject *viewmol_showWarnings(PyObject *self, PyObject *args)
+{
+  int warning;
+
+  if (checkInterrupt()) return(NULL);
+  if (!PyArg_ParseTuple(args, "i", &warning)) return(NULL);
+  if (warning != TRUE && warning != FALSE)
+  {
+      PyErr_SetString(PyExc_ValueError, "Argument must be ON or OFF");
+      return(NULL);
+  }
+  showWarning=warning;
+  redraw(VIEWER);
+  Py_INCREF(Py_None);
+  return(Py_None);
+}
+
+static PyObject *viewmol_getWindowSize(PyObject *self, PyObject *args)
+{
+  PyObject *tuple;
+  Dimension width, height;
+
+  if (checkInterrupt()) return(NULL);
+  if ((tuple=PyTuple_New(2)))
+  {
+    XtVaGetValues(windows[VIEWER].widget, XtNwidth, &width, XtNheight, &height, NULL);
+    PyTuple_SetItem(tuple, 0, PyInt_FromLong((long)width));
+    PyTuple_SetItem(tuple, 1, PyInt_FromLong((long)height));
+    return(tuple);
+  }
+  Py_INCREF(Py_None);
+  return(Py_None);
+}
+
 static PyObject *viewmol_quit(PyObject *self, PyObject *args)
 {
   if (checkInterrupt()) return(NULL);
@@ -543,9 +600,10 @@ void initViewmolModule(void)
   PyDict_SetItemString(d, "LINE", PyInt_FromLong((long)GLU_LINE));
   PyDict_SetItemString(d, "SURFACE", PyInt_FromLong((long)GLU_FILL));
   PyDict_SetItemString(d, "TIFF", PyInt_FromLong((long)TIFFFILE));
+  PyDict_SetItemString(d, "PNG", PyInt_FromLong((long)PNGFILE));
   PyDict_SetItemString(d, "HPGL", PyInt_FromLong((long)HPGL));
   PyDict_SetItemString(d, "POSTSCRIPT", PyInt_FromLong((long)POSTSCRIPT));
-  PyDict_SetItemString(d, "RAYSHADE", PyInt_FromLong((long)RAYTRACER));
+  PyDict_SetItemString(d, "RAYTRACER", PyInt_FromLong((long)RAYTRACER));
   PyDict_SetItemString(d, "REACTION", PyInt_FromLong((long)(-1)));
   Py_DECREF(v);
   m=PyImport_Import(PyString_FromString("sys"));
