@@ -4,12 +4,15 @@
 *                                                                              *
 *                             W A V E F O R M . C                              *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: waveform.c,v 1.5 2000/12/10 15:18:53 jrh Exp $
+* $Id: waveform.c,v 1.6 2003/11/07 11:17:24 jrh Exp $
 * $Log: waveform.c,v $
+* Revision 1.6  2003/11/07 11:17:24  jrh
+* Release 2.4
+*
 * Revision 1.5  2000/12/10 15:18:53  jrh
 * Release 2.3
 *
@@ -57,6 +60,7 @@ extern int checkFile(char **);
 extern void calcmo(void);
 extern void redraw(int);
 extern void drawMolecule(Widget, caddr_t, XmDrawingAreaCallbackStruct *);
+extern void *getmem(size_t, size_t);
 extern void fremem(void **);
 extern void setMenuItem(int, int);
 extern int  makeAnnotation(int, int, float, float, float, int, const GLfloat *,
@@ -65,7 +69,7 @@ extern void deleteAnnotation(int *);
 extern void pixelToWorld(int, double *, double *);
 extern int StringWidth(XFontStruct *, char *);
 extern int StringHeight(XFontStruct *);
-extern char *bfname(int);
+/* extern char *bfname(int);*/
 extern int messgb(Widget, int, char *, struct PushButtonRow *, int);
 extern void GetMessageBoxButton(Widget, XtPointer, caddr_t);
 extern void setCursor(Widget, int);
@@ -90,36 +94,30 @@ extern Widget topShell;
 extern char moloch[];
 extern Pixel stdcol[9];
 
-static Widget dialog;
+static Widget dialog, slider2;
 static int iwavef_save, interp_save;
 static double level_save, gridres_save;
 
 void wavefunctionDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
 {
   Widget form, board, form1, checkbox1, checkbox2, sep1, sep2, sep3, sep4;
-  Widget slider1, slider2, label, button;
-  register int i;
-  static struct TOGGLE toggle1[5];
+  Widget slider1, label, button;
+  register int i, j;
+  struct TOGGLE *toggle1;
   static struct TOGGLE toggle2[3];
-  static struct PushButtonRow buttons[] = {
+  struct PushButtonRow buttons[] = {
     { "ok", wavefunctionDialogExit, (XtPointer)TRUE, NULL },
     { "cancel", wavefunctionDialogExit, (XtPointer)FALSE, NULL },
   };
-  static struct PushButtonRow checkbox1_buttons[] = {
-    { "all_off", GetWave, (XtPointer)&toggle1[0], NULL },
-    { "basis_function", GetWave, (XtPointer)&toggle1[1], NULL },
-    { "basis_in_mo", GetWave, (XtPointer)&toggle1[2], NULL },
-    { "molecular_orbital", GetWave, (XtPointer)&toggle1[3], NULL },
-    { "electron_density", GetWave, (XtPointer)&toggle1[4], NULL },
-  };
-  static struct PushButtonRow checkbox2_buttons[] = {
+  struct PushButtonRow *checkbox1_buttons;
+  struct PushButtonRow checkbox2_buttons[] = {
     { "none", GetUnit, (XtPointer)&toggle2[0], NULL },
     { "linear", GetUnit, (XtPointer)&toggle2[1], NULL },
     { "logarithmic", GetUnit, (XtPointer)&toggle2[2], NULL },
   };
   static struct SLIDER surface, gridsize;
   struct MOLECULE *mol;
-  int levelInt;
+  int nDrawable, start, levelInt, minimum, maximum;
   short decimals;
 
   if (windows[VIEWER].set >= 0)
@@ -137,23 +135,53 @@ void wavefunctionDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
   gridsize.draw=NULL;
 
   dialog=initShell(windows[VIEWER].widget, "wavefunctionForm",
-			 &board, &form);
+                   &board, &form);
 
   form1=XtVaCreateWidget("controlarea", xmFormWidgetClass, form, NULL);
 
-  for (i=0; i<5; i++)
+  if (mol->basisset)
+  {
+    start=ALL_OFF;
+    nDrawable=DENSITY;
+  }
+  else
+  {
+    start=DENSITY;
+    nDrawable=ALL_OFF;
+  }
+  for (i=0; i<mol->ngridobjects; i++)
+    if (mol->gridObjects[i].type & GRIDREAD) nDrawable++;
+
+  toggle1=(struct TOGGLE *)getmem((size_t)nDrawable, sizeof(struct TOGGLE));
+  checkbox1_buttons=(struct PushButtonRow *)getmem((size_t)nDrawable, sizeof(struct PushButtonRow));
+  toggle1[0].var=&iwavef;
+  toggle1[0].draw=NULL;
+  toggle1[0].value=ALL_OFF;
+  checkbox1_buttons[0].callback=GetWave;
+  checkbox1_buttons[0].client_data=(XtPointer)&toggle1[0];
+  checkbox1_buttons[0].widget=(Widget)NULL;
+  checkbox1_buttons[0].label="all_off";
+  j=0;
+  for (i=1; i<nDrawable; i++)
   {
     toggle1[i].var=&iwavef;
     toggle1[i].draw=NULL;
+    toggle1[i].value=i+start;
+    checkbox1_buttons[i].callback=GetWave;
+    checkbox1_buttons[i].client_data=(XtPointer)&toggle1[i];
+    checkbox1_buttons[i].widget=(Widget)NULL;
+    if (toggle1[i].value > DENSITY)
+      checkbox1_buttons[i].label=mol->gridObjects[j++].text;
   }
-  toggle1[0].value=ALL_OFF;
-  toggle1[1].value=BASIS_FUNCTION;
-  toggle1[2].value=BASIS_IN_MO;
-  toggle1[3].value=MOLECULAR_ORBITAL;
-  toggle1[4].value=DENSITY;
-
-  checkbox1=CreateToggleBox(form1, checkbox1_buttons, XtNumber(checkbox1_buttons),
-                            XmVERTICAL, 1, True, iwavef-1);
+  if (mol->basisset)
+  {
+    checkbox1_buttons[1].label="basis_function";
+    checkbox1_buttons[2].label="basis_in_mo";
+    checkbox1_buttons[3].label="molecular_orbital";
+    checkbox1_buttons[4].label="electron_density";
+  }
+  checkbox1=CreateToggleBox(form1, checkbox1_buttons, nDrawable, XmVERTICAL, 1,
+                            True, iwavef-start);
 
   if (mol->orbitals != NULL)
   {
@@ -176,12 +204,12 @@ void wavefunctionDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
                            XmNtopAttachment, XmATTACH_FORM,
                            NULL);
   sep1=XtVaCreateManagedWidget("sep1", xmSeparatorWidgetClass, form1,
-                              XmNtraversalOn, False,
-                              XmNleftAttachment, XmATTACH_FORM,
-                              XmNrightAttachment, XmATTACH_FORM,
-                              XmNtopAttachment, XmATTACH_WIDGET,
-                              XmNtopWidget, checkbox1,
-                              NULL);
+                               XmNtraversalOn, False,
+                               XmNleftAttachment, XmATTACH_FORM,
+                               XmNrightAttachment, XmATTACH_FORM,
+                               XmNtopAttachment, XmATTACH_WIDGET,
+                               XmNtopWidget, checkbox1,
+                               NULL);
 
   label=XtVaCreateManagedWidget("levelLabel", xmLabelWidgetClass, form1,
                                 XmNleftAttachment, XmATTACH_FORM,
@@ -200,6 +228,9 @@ void wavefunctionDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
                                   NULL);
   XtVaGetValues(slider1, XmNdecimalPoints, &decimals, NULL);
   levelInt=(int)(level*pow((double)10.0, (double)decimals));
+  XtVaGetValues(slider1, XmNminimum, &minimum, XmNmaximum, &maximum, NULL);
+  if (minimum > levelInt) XtVaSetValues(slider1, XmNminimum, levelInt, NULL);
+  if (maximum < levelInt) XtVaSetValues(slider1, XmNmaximum, levelInt, NULL);
   XtVaSetValues(slider1, XmNvalue, levelInt, NULL);
   surface.number=&level;
   surface.decimals=decimals;
@@ -262,6 +293,8 @@ void wavefunctionDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
                                   XmNtopAttachment, XmATTACH_WIDGET,
                                   XmNtopWidget, label,
                                   NULL);
+  if (iwavef > DENSITY)
+    gridres=(double)(mol->gridObjects[iwavef-DENSITY-1].ngridpoints[0]);
   if (gridres > 0.0)
     XtVaSetValues(slider2, XmNvalue, (int)gridres, NULL);
   else
@@ -270,6 +303,8 @@ void wavefunctionDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
     gridres=(double)levelInt;
   }
   XtAddCallback(slider2, XmNvalueChangedCallback, (XtCallbackProc)GetSlider, &gridsize);
+  if (iwavef > DENSITY)
+    XtVaSetValues(slider2, XmNsensitive, False, NULL);
   button=XtVaCreateManagedWidget("automatic", xmToggleButtonWidgetClass, form1,
                                  XmNleftAttachment, XmATTACH_FORM,
                                  XmNrightAttachment, XmATTACH_FORM,
@@ -328,6 +363,9 @@ void wavefunctionDialogExit(Widget widget, caddr_t which, XmPushButtonCallbackSt
                                 calcmo();
                               }
                               break;
+      /* Grid read from input */
+      default:                selectAtom=FALSE;
+                              break;
     }
   }
   XtDestroyWidget(dialog);
@@ -366,7 +404,8 @@ void annotateWavefunction(void)
   {
     c=getStringResource(topShell, "basisfunctionTitle");
     sprintf(line1, c, mol->ibasfu+1, mol->atoms[bfatom].name, bfatom+1,
-            bfname(mol->ibasfu));
+/*          bfname(mol->ibasfu));*/
+            mol->atoms[bfatom].basisFunctionNames[mol->ibasfu]);
     wavefunctionAnnotation[0]=makeAnnotation(wavefunctionAnnotation[0],
                               CENTERED, 0.0, 1.0, 0.0, stdcol[BLACK], black,
                               0, 0, line1);
@@ -376,7 +415,8 @@ void annotateWavefunction(void)
   {
     c=getStringResource(topShell, "basisfunctionInMOTitle");
     sprintf(line1, c, mol->ibasfu+1, mol->imo+1, mol->atoms[bfatom].name, bfatom+1,
-            mol->orbitals[mol->imo].coeff[mol->ibasfu], bfname(mol->ibasfu));
+/*          mol->orbitals[mol->imo].coeff[mol->ibasfu], bfname(mol->ibasfu));*/
+            mol->orbitals[mol->imo].coeff[mol->ibasfu], mol->atoms[bfatom].basisFunctionNames[mol->ibasfu]);
     wavefunctionAnnotation[0]=makeAnnotation(wavefunctionAnnotation[0],
                               CENTERED, 0.0, 1.0, 0.0, stdcol[BLACK], black,
                               0, 0, line1);
@@ -482,12 +522,15 @@ void deleteGridObjects(void)
   for (i=0; i<nmolecule; i++)
   {
     for (j=0; j<molecules[i].ngridobjects; j++)
-      fremem((void **)&(molecules[i].gridObjects[j].grid));
-    if (molecules[i].ngridobjects != 0)
     {
-      fremem((void **)&(molecules[i].gridObjects));
-      molecules[i].ngridobjects=0;
+      if (!(molecules[i].gridObjects[j].type & GRIDREAD))
+	{
+        fremem((void **)&(molecules[i].gridObjects[j].grid));
+	  molecules[i].ngridobjects--;
+      }
     }
+    if (molecules[i].ngridobjects == 0)
+      fremem((void **)&(molecules[i].gridObjects));
   }
   annotateWavefunction();
 }
@@ -496,6 +539,7 @@ void GetWave(Widget widget, struct TOGGLE *which, XmToggleButtonCallbackStruct *
 {
   static struct PushButtonRow button[] = {{"continue", GetMessageBoxButton, (XtPointer)0, NULL}};
   char *word, line[MAXLENLINE];
+  register int i;
 
   if (data->set)
   {
@@ -509,6 +553,16 @@ void GetWave(Widget widget, struct TOGGLE *which, XmToggleButtonCallbackStruct *
       return;
     }
     *(which->var)=which->value;
+    if (which->value > DENSITY)
+    {
+      i=which->value-DENSITY-1;
+      XtVaSetValues(slider2, XmNsensitive, False,
+                             XmNvalue, molecules[windows[VIEWER].set].gridObjects[i].ngridpoints[0],
+                             NULL);
+      gridres=(double)molecules[windows[VIEWER].set].gridObjects[i].ngridpoints[0];
+    }
+    else
+      XtVaSetValues(slider2, XmNsensitive, True, XmNvalue, (int)gridres, NULL);
   }
   if (*(which->draw) != NULL) (*(which->draw))((Widget)0, (caddr_t)0, (caddr_t)0);
 }
