@@ -4,12 +4,15 @@
 *                                                                              *
 *                               W I N D O W . C                                *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 2000                   *
+*                 Copyright (c) Joerg-R. Hill, October 2003                    *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: window.c,v 1.5 2000/12/10 15:19:04 jrh Exp $
+* $Id: window.c,v 1.6 2003/11/07 11:17:31 jrh Exp $
 * $Log: window.c,v $
+* Revision 1.6  2003/11/07 11:17:31  jrh
+* Release 2.4
+*
 * Revision 1.5  2000/12/10 15:19:04  jrh
 * Release 2.3
 *
@@ -33,7 +36,8 @@
 
 void setWindowTitle(Widget widget, char *title)
 {
-  XtVaSetValues(XtParent(widget), XmNtitle, title, NULL);
+  if (title != NULL)
+    XtVaSetValues(XtParent(widget), XmNtitle, title, NULL);
 
 /*XTextProperty text;
 
