@@ -8,8 +8,11 @@
 *                                                                              *
 ********************************************************************************
 *
-* $Id: xfont.c,v 1.6 2003/11/07 11:17:38 jrh Exp $
+* $Id: xfont.c,v 1.7 2004/08/29 15:02:57 jrh Exp $
 * $Log: xfont.c,v $
+* Revision 1.7  2004/08/29 15:02:57  jrh
+* Release 2.4.1
+*
 * Revision 1.6  2003/11/07 11:17:38  jrh
 * Release 2.4
 *
@@ -93,21 +96,33 @@ void printString(char *s, double x, double y, double z, double width,
 
 int StringWidth(XFontStruct *font, char *string)
 {
-  return(XTextWidth(font, string, strlen(string)));
+  if (font)
+    return(XTextWidth(font, string, strlen(string)));
+  else
+    return(0);
 }
 
 int StringHeight(XFontStruct *font)
 {
-  return(font->ascent+font->descent);
+  if (font)
+    return(font->ascent+font->descent);
+  else
+    return(0);
 }
 
 int StringAscent(XFontStruct *font)
 {
-  return(font->ascent);
+  if (font)
+    return(font->ascent);
+  else
+    return(0);
 }
 
 void deleteFontList(GLuint base, XFontStruct *font)
 {
-  glDeleteLists(base, font->max_char_or_byte2-font->min_char_or_byte2+1);
-  fremem((void **)&font);
+  if (font)
+  {
+    glDeleteLists(base, font->max_char_or_byte2-font->min_char_or_byte2+1);
+    fremem((void **)&font);
+  }
 }
