@@ -45,8 +45,9 @@ class autotest:
     self.label1.text("Automatic tests")
     self.label1.setColor(0.0, 0.0, 1.0, 0.0)
     self.label2=label.label()
+    viewmolpath=os.getenv("VIEWMOLPATH")
     for file in ["examples/turbomole/control", "examples/gulp/urea.out", "examples/discover/benzene.cor", "examples/dmol/quartz.outmol", "examples/gamess/c10h8n2.out", "examples/gaussian/mmdc1.log", "examples/mopac/adamantane.out", "examples/pqs/cpcpm.out", "examples/pdb/gpc.pdb"]:
-      self.testMolecule(os.environ['VIEWMOLPATH'] + "/" + file)
+      self.testMolecule(viewmolpath + "/" + file)
     self.createMolecule()
     self.thermodynamics()
     self.label2.delete()
@@ -90,12 +91,9 @@ class autotest:
         del hist
       self.atomTest(mol[0])
       self.elementTest(mol[0])
-      osname=os.popen("uname -s")
-      if osname.read() != "FreeBSD\n":    # Saving blocks on FreeBSD
-        for i in ['car', 'arc', 'mol', 'tm']:
-          viewmol.save(mol[0], "test.file", i)
-          os.unlink("test.file")
-      osname.close()
+      for i in ['car', 'arc', 'mol', 'tm']:
+        viewmol.save(mol[0], "test.file", i)
+        os.unlink("test.file")
       self.testSaving(viewmol, "molecule.test")
       viewmol.delete(mol[0])
 
@@ -415,21 +413,22 @@ class autotest:
 
   def thermodynamics(self):
     self.label1.text("Thermodynamics")
-    molecule1=viewmol.load(os.environ['VIEWMOLPATH'] + '/examples/reaction/hio3.outmol')
+    viewmolpath=os.getenv("VIEWMOLPATH")
+    molecule1=viewmol.load(viewmolpath + "/examples/reaction/hio3.outmol")
     molecule1.reaction(molecule.__dict__['PRODUCT'])
     molecule1.translate(-1.0, 1.0, 0.0)
-    molecule2=viewmol.load(os.environ['VIEWMOLPATH'] + '/examples/reaction/i2.outmol')
+    molecule2=viewmol.load(viewmolpath + "/examples/reaction/i2.outmol")
     molecule2.reaction(molecule.__dict__['REACTANT'])
     molecule2.rotate(90.0, 0.0, 0.0)
     molecule2.translate(1.0, 1.0, 0.0)
-    molecule3=viewmol.load(os.environ['VIEWMOLPATH'] + '/examples/reaction/hno3.outmol')
+    molecule3=viewmol.load(viewmolpath + "/examples/reaction/hno3.outmol")
     molecule3.reaction(molecule.__dict__['REACTANT'])
     molecule3.translate(-1.0, -1.0, 0.0)
-    molecule4=viewmol.load(os.environ['VIEWMOLPATH'] + '/examples/reaction/no.outmol')
+    molecule4=viewmol.load(viewmolpath + "/examples/reaction/no.outmol")
     molecule4.reaction(molecule.__dict__['PRODUCT'])
     molecule4.rotate(90.0, 0.0, 0.0)
     molecule4.translate(1.0, -1.0, 0.0)
-    molecule5=viewmol.load(os.environ['VIEWMOLPATH'] + '/examples/reaction/h2o.outmol')
+    molecule5=viewmol.load(viewmolpath + "/examples/reaction/h2o.outmol")
     molecule5.reaction(molecule.__dict__['PRODUCT'])
     viewmol.showThermodynamics(viewmol.__dict__['REACTION'])
     self.redrawWait(5)
